import { YUVRender } from "../utils/yuv_render";
import { RtcRoomStats, UserOfflineReasonType, AVSyncState, LocalStreamStats, RemoteStreamStats, MediaStreamType, StreamRemoveReason, SubscribeState, SubscribeConfig, RangeAudioInfo, ForwardStreamStateInfo, ForwardStreamEventInfo, NetworkQualityStats, VideoFrameInfo, IVideoFrame, WarningCode, ErrorCode, ConnectionState, AudioMixingState, AudioMixingError, NetworkType, PerformanceAlarmMode, PerformanceAlarmReason, SysStats, StreamIndex, RemoteStreamKey, RemoteStreamSwitch, RemoteAudioState, RemoteAudioStateChangeReason, LocalAudioStreamState, LocalAudioStreamError, LocalVideoStreamState, LocalVideoStreamError, RemoteVideoState, RemoteVideoStateChangeReason, RtcUser, FirstFrameSendState, FirstFramePlayState, MessageSendResultCode, StreamMixingEvent, SingleStreamPushEvent, StreamMixingType, RecordingInfo, RecordingProgress, IAudioFrame, LocalAudioPropertiesInfo, RemoteAudioPropertiesInfo, SourceWantedData, EchoTestResult, UserInfo } from "./index";
/**
 * @brief User information
 */
export interface UserRenderInfo {
    /**
     * @brief User ID. The string matches the regular expression: `[a-zA-Z0-9_@\-]{1,128}`.
     */
    userId: string;
    /**
     * @brief Video render
     */
    videoRender?: YUVRender | null;
    /**
     * @brief Screen render
     */
    screenRender?: YUVRender | null;
    /**
     * @brief Render options
     */
    renderOptions?: any;
}
export interface RoomData {
    localUser: UserRenderInfo;
    remoteUsers: Map<string, UserRenderInfo>;
}
export declare type SharedRoomInfo = Map<string, RoomData>;
/**
 * @hidden
 */
export declare type EventType = {
    Type: string;
    Object: {
        [key: string]: any;
    };
};
/**
 * @list 85530
 * @detail 85533
 */
export interface RTCROOMCALLBACK {
    /**
     * @brief Callback on room state changes. You will receive this callback when you join the room, leave the room, or receive room relating warnings and errors.
     * @param room_id Room ID
     * @param uid User ID
     * @param state Room state code.
     *              + 0: Success.
     *              + !0: Failure.
     * @param extra_info Extra information.
     *                 `join_type` indicates the type of room the user joins. `0` means the user joins the room for the first time, and `1` means the user rehoins the room.
     *                 `elapsed` indicates the time interval from calling [joinRoom](#joinroom) to successfully joining room, in ms.
     */
    onRoomStateChanged(room_id: string, uid: string, state: number, extra_info: string): void;
    /**
     * @brief Callback on stream state changes. You will receive this callback when you receive stream relating warnings and errors.
     * @param room_id Room ID
     * @param uid User ID
     * @param state Room state code.
     *              + 0: Success.
     *              + !0: Failure.
     * @param extra_info Extra information. Currently unavailable.
     */
    onStreamStateChanged(room_id: string, uid: string, state: number, extra_info: string): void;
    /**
     * @brief After leaving the room successfully, receives the callback.
     * @param stats Statistics for this call.
     * @notes + When the user calls the [leaveRoom](85532#leaveroom), the SDK will stop all publishing subscription streams and release all call-related media resources. After that, the user receives this callback.
     * + If calling [leaveRoom](85532#leaveroom) and then [destroy](85532#destroy) immediately after, the user will not receive this callback.
     * + If the app needs to use the media resources of the device for purposes other than RTC, you should init the resources after receiving this callback. Receiving this callback ensures that the resources are not occupied by RTC SDK.
     */
    onLeaveRoom(stats: RtcRoomStats): void;
    /**
     * @brief You will receive this callback in following cases:
     *        + The remote user calls `setUserVisibility` turns visible and joins your room.
     *        + The remote visible user is disconnected and then reconnected to your room.
     *        + The invisible remote user in your room calls `setUserVisibility` and turns visible.
     *        + You join the room when there are visible users in the room.
     * @param user_info User ID
     * @param elapsed Live streaming host role The user calls [joinRoom](85532#joinroom) to join the room The time in ms that other users in the room receive the event experience.
     */
    onUserJoined(user_info: UserInfo, elapsed: number): void;
    /**
     * @brief This callback is triggered when a remote user is disconnected or turns invisible.
     * @param uid ID of the user who leaves the room, or switches to invisible.
     * @param reason Reason to leave the room
     */
    onUserLeave(uid: string, reason: UserOfflineReasonType): void;
    /**
     * @brief You will be informed 30 sec before the expiration via this callback.
     * @notes Call [updateToken](85532#updatetoken) to renew the Token. If the Token expired, the user would be removed from the room and not be able to continue the call.
     */
    onTokenWillExpire(): void;
    /**
     * @brief Stream publisher will receive this callback when the A/V synchronization state changes after `setMultiDeviceAVSync` is called.
     * @param state A/V synchronization state
     */
    onAVSyncStateChange(state: AVSyncState): void;
    /**
     * @brief In-room call statistics callback.
     *        After the user enters the room and starts the call, he receives this callback every 2s.
     * @param stats Current RtcEngine statistics.
     */
    onRoomStats(stats: RtcRoomStats): void;
    /**
     * @brief After the published stream is successful, you receive this callback every 2s to understand the network quality information of the published stream during this cycle.
     * @param stats Current RtcEngine statistics.
     */
    onLocalStreamStats(stats: LocalStreamStats): void;
    /**
     * @brief Receive this callback every 2s to learn the network quality information of the stream published by the subscribed remote user during this cycle.
     * @param stats Current RtcEngine statistics.
     */
    onRemoteStreamStats(stats: RemoteStreamStats): void;
    /**
     * @brief Callback on new media streams captured by camera/microphone in the room.
     * @param uid The ID of the remote user who published the stream.
     * @param type Media stream type.
     * @notes You will receive this callback after a remote user successfully published media streams captured by camera/microphone in the room with [publishStream](85532#publishstream). Then you can choose whether to call [subscribeStream](85532#subscribestream) to subscribe to the streams or not.
     */
    onUserPublishStream(uid: string, type: MediaStreamType): void;
    /**
     * @brief Callback on removal of remote media stream captured by camera/microphone.
     * @param uid The ID of the remote user who removed the stream.
     * @param type Media stream type
     * @param reason The reason for the removal
     * @notes After receiving this callback, you can choose whether to call [unsubscribeStream](85532#unsubscribestream) to unsubscribe from the streams or not.
     */
    onUserUnpublishStream(uid: string, type: MediaStreamType, reason: StreamRemoveReason): void;
    /**
     * @brief Callback on new screen sharing media streams from remote users in the room.
     * @param uid The ID of the remote user who published the stream.
     * @param type Media stream type
     * @notes You will receive this callback after a remote user successfully published screen sharing streams in the room with [publishScreen](#publishscreen). Then you can choose whether to call [subscribeScreen](85532#subscribescreen) to subscribe to the streams or not.
     */
    onUserPublishScreen(uid: string, type: MediaStreamType): void;
    /**
     * @brief Callback on removal of screen sharing media streams from remote users in the room.
     * @param uid The ID of the remote user who removed the stream.
     * @param type Media stream type
     * @param reason The reason for the removal
     * @notes After receiving this callback, you can choose whether to call [unsubscribeScreen](#unsubscribescreen) to unsubscribe from the streams or not.
     */
    onUserUnpublishScreen(uid: string, type: MediaStreamType, reason: StreamRemoveReason): void;
    /**
     * @brief Callback on subscription status of media streams
     * @param state_code Subscription status of media streams
     * @param user_id The ID of the user who published the stream.
     * @param info Configurations of stream subscription
     */
    onStreamSubscribed(state_code: SubscribeState, user_id: string, info: SubscribeConfig): void;
    /**
     * @brief All the users in the room will get informed via this callback when a user is banned or the ban of the user has been lifted by calling BanUserStream/UnbanUserStream on the server side.
     * @param uid User ID of the video stream that was disabled/unbanned
     * @param banned Video stream sending status
     *         + True: Video stream sending was disabled
     *         + False: Video stream sending was unbanned
     * @notes + When the specified user in the room is disabled/unbanned Video stream sending, all users in the room will receive the callback.
     * + If the banned user leaves or disconnects and then rejoins the room, the user is still banned from publishing audio stream, and all users in the room will be informed via the callback.
     * + After the specified user is banned, other users in the room will check out and enter the room again, and will receive the callback again.
     * + If the conference mode is enabled in the console, only the user whose stream is banned will receive this callback.
     */
    onVideoStreamBanned(uid: string, banned: boolean): void;
    /**
     * @brief All the users in the room will get informed via this callback when a user is banned or the ban of the user has been lifted by calling BanUserStream/UnbanUserStream on the server side.
     * @param uid Disabled/unbanned audio stream user ID
     * @param banned Audio stream sending status
     * + True: audio stream sending is disabled
     * + False: audio stream sending is unbanned
     * @notes + Specified users in the room are prohibited/all users in the room when audio stream sending is unbanned Will receive the callback.
     * + If the banned user checks out and then enters the room, it will still be banned status, and everyone in the room will receive the callback again.
     * + If the banned user is disconnected and reconnected to the room, it will still be banned status, and only the person will receive the callback again.
     * + After the specified user is banned, other users in the room will check out and enter the room again, and will receive the callback again.
     * + The same room is created again after dissolution, and the state in the room is empty.
     * + If the conference mode is enabled in the console, only the user whose stream is banned will receive this callback.
     */
    onAudioStreamBanned(uid: string, banned: boolean): void;
    /**
     * @brief Receives a callback for broadcast messages in the room.
     * @param uid Message sender ID
     * @param message Received message content
     * @notes Other users in the same room will receive this callback when they call [sendRoomMessage](85532#sendroommessage) to send a broadcast message.
     */
    onRoomMessageReceived(uid: string, message: string): void;
    /**
     * @brief Receives a callback to a binary broadcast message in the room.
     * @param uid Message sender ID
     * @param message Binary message content received
     * @notes Other users in the same room call [sendRoomBinaryMessage](#sendroombinarymessage) Receive this callback when sending a binary broadcast message.
     */
    onRoomBinaryMessageReceived(uid: string, message: string): void;
    /**
     * @brief Receive this callback when you receive a text message (P2P) from another user in the room.
     * @param uid Message sender ID.
     * @param message The content of the received text message.
     * @notes You must call the [sendUserMessage](85532#sendusermessage) method before you can receive the callback.
     */
    onUserMessageReceived(uid: string, message: string): void;
    /**
     * @brief A single user receives a callback (P2P) of binary messages from other uid-owned users in the same room.
     * @param uid Message sender ID.
     * @param message The content of the received binary message.
     * @notes When other users in the same room call [sendUserBinaryMessage](85532#senduserbinarymessage) to send binary messages to local users, local users will receive the callback.
     */
    onUserBinaryMessageReceived(uid: string, message: string): void;
    /**
     * @brief After sending a text or binary message (P2P) to a single user in the room, the message sender receives a callback with the result of the message.
     * @param msgid The ID of this message.
     * @param error Text or binary message sending results.
     * @notes You must first call the [sendUserMessage](85532#sendusermessage) or [sendUserBinaryMessage](85532#senduserbinarymessage) interface to receive this callback.
     */
    onUserMessageSendResult(msgid: number, error: number): void;
    /**
     * @brief You receives this callback for the nofication of the result of calling `sendRoomMessage` or `sendRoomBinaryMessage`.
     * @param msgid ID of this message
     * @param error Message sending result
     */
    onRoomMessageSendResult(msgid: number, error: number): void;
    /**
     * @brief Callback returning the state and errors during relaying the audio stream to each of the rooms
     * @param infos Array of the state and errors of each designated room.
     * @param info_count Count
     */
    onForwardStreamStateChanged(infos: ForwardStreamStateInfo[], info_count: number): void;
    /**
     * @brief Callback returning the events during relaying the audio stream to each room
     * @param infos Array of the event of each designated room.
     * @param info_count Count
     */
    onForwardStreamEvent(infos: ForwardStreamEventInfo[], info_count: number): void;
    /**
     * @brief Callback about the current attenuation coefficient of remote users.
     * @param range_audio_info Array containing audio stream information
     * @param len Length of the array.
     * @notes + In manual subscription mode, when any user in the room calls [updateRangePosition](85532#updaterangeposition) to update their position or [updateReceiveRange](85532#updatereceiverange) to update their audio receiving range, the relative distance between this user and other users in the room will change, and the attenuation coefficient calculated accordingly will change as well, which will be notified to users.
     * + You can determine whether to subscribe to a remote user's audio stream based on the attenuation coefficient of that user shown in this callback.
     * + You will not receive this callback immediately after updating your location or audio receiving range. SDK calculates the attenuation coefficient every 500 ms, and only trigger this callback if the result of the calculation is different from the previous one, or if the result is the same but more than 3 seconds after the last calculation.
     */
    onRangeAudioInfo(range_audio_info: RangeAudioInfo, len: number): void;
    /**
     * @brief Report the network quality of the users every 2s after the local user joins the room.
     * @param localQuality Local network quality
     * @param remoteQualities Network quality of the subscribed users.
     */
    onNetworkQuality(localQuality: NetworkQualityStats, remoteQualities: NetworkQualityStats[]): void;
}
/**
 * @list 85530
 * @detail 85533
 */
export interface RTCVIDEOCALLBACK {
    /**
     * @brief Callback of successfully decoding of the first audio frame of the public stream
     *        Refer to [`startPlayPublicStream`](#startplaypublicstream) for details about subsribing to a public stream.
     * @param public_stream_id ID of the public stream
     */
    onFirstPublicStreamAudioFrame(public_stream_id: string): void;
    /**
     * @brief Callback of successfully decoding of the first audio frame of the public stream
     * @param room_id Room ID
     * @param public_stream_id ID of the public stream
     * @param error_code Error code
     * @notes Refer to [`startPlayPublicStream`](85532#startplaypublicstream) for details about subsribing to a public stream.
     */
    onPushPublicStreamResult(room_id: string, public_stream_id: string, error_code: number): void;
    /**
     * @brief Callback of successfully decoding of the first video frame of the public stream
     * @param public_stream_id ID of the public stream
     * @param video_frame_info Information of the video stream.
     * @notes Refer to [`startPlayPublicStream`](85532#startplaypublicstream) for details about subsribing to a public stream.
     */
    onFirstPublicStreamVideoFrameDecoded(public_stream_id: string, video_frame_info: VideoFrameInfo): void;
    /**
     * @brief Callback of the SEI carried by the public video stream
     *        You will receive SEI by this callback if the public stream published by calling [`startPlayPublicStream`](#startplaypublicstream) carrying SEI.
     * @param public_stream_id ID of the public stream
     * @param message SEI(supplemental enhancement information) carried by the public video stream
     * @notes You will receive SEI from all the video frames if the SEI do not have conflicts.
     *       However, if SEI from video frames have conflicts, you will receive only one of them.
     */
    onPublicStreamSEIMessageReceived(public_stream_id: string, message: string): void;
    /**
     * @brief Callback of the result of subscribing to the public stream
     *        You will be informed of the result of subscribing to the public stream by this callback after calling [`startPlayPublicStream`](#startplaypublicstream).
     * @param public_stream_id
     * @param error_code Code for the result of playing the public stream.
     */
    onPlayPublicStreamResult(public_stream_id: string, error_code: number): void;
    /**
     * @brief Get the successfully captured local screen video frames for custom processing or rendering.
     * @param frame Video data
     */
    onLocalScreenFrame(frame: IVideoFrame): void;
    /**
     * @brief Get the successfully captured local camera stream for custom processing or rendering.
     * @param frame
     */
    onLocalVideoFrame(frame: IVideoFrame): void;
    /**
     * @brief Get the successfully captured remote screen video frames for custom processing or rendering.
     * @param frame Video data
     */
    onRemoteScreenFrame(frame: IVideoFrame): void;
    /**
     * @brief Get the successfully captured remote camera stream for custom processing or rendering.
     * @param frame Video data
     * @notes PixelFormat of the video data from different platforms could be different.
     */
    onRemoteVideoFrame(frame: IVideoFrame): void;
    /**
     * @brief You can get the video data of the public stream and pass it to the external renderer.
     * @param frame Video data
     */
    onPublicStreamVideoFrame(frame: IVideoFrame): void;
    /**
     * @brief This callback informs you of a warning message.
     * @param warn Warning code
     */
    onWarning(warn: WarningCode): void;
    /**
     * @brief This callback informs you of an error message.
     * @param error_code Error code
     * @param error_message Error message
     */
    onError(error_code: ErrorCode, error_message: string): void;
    /**
     * @brief This callback informs you at the end of playing a local audio file.
     * @notes Call [startAudioMixing](#startaudiomixing) to start a local audio file.
     */
    onAudioMixingFinished(): void;
    /**
     * @brief This callbck infroms you when the state of playing a local audio file changes.
     * @param id ID of the mixing task
     * @param state State of playing a local audio file
     * @param error Error code
     * @notes The callback will be triggered in the following timings.
     * + When the [startAudioMixing](85532#startaudiomixing) method is successfully called, a callback with a state value of kAudioMixingStatePlaying will be triggered; otherwise the state will be triggered A callback with a value of kAudioMixingStateFailed.
     * + When [startAudioMixing](85532#startaudiomixing) is called repeatedly with the same ID, the latter overrides the previous, and this callback notifies the previous mix has stopped with kAudioMixingStateStopped.
     * + When calling the [pauseAudioMixing](85532#pauseaudiomixing) method to pause playback successfully, a callback with a state value of kAudioMixingStatePaused will be triggered; otherwise, a callback with a state value of kAudioMixingStateFailed will be triggered.
     * + When the [resumeAudioMixing](85532#resumeaudiomixing) method is called to resume playing successfully, a callback with a state value of kAudioMixingStatePlaying will be triggered; otherwise, a callback with a state value of kAudioMixingStateFailed will be triggered.
     * + When calling the [stopAudioMixing](85532#StopAudioMixing) method to pause playback successfully, a callback with a state value of kAudioMixingStateStopped will be triggered; otherwise, a callback with a state value of kAudioMixingStateFailed will be triggered.
     * + The end of playback triggers a callback with the state value kAudioMixingStateFinished.
     */
    onAudioMixingStateChanged(id: number, state: AudioMixingState, error: AudioMixingError): void;
    /**
     * @brief Callback for playback progress of mixed audio files
     * @param mix_id ID of the mixing task
     * @param progress The current playback progress (ms) of the mixed audio file
     * @notes After calling [setAudioMixingProgressInterval](#setaudiomixingprogressinterval) to set the time interval to a value greater than 0, or calling [startAudioMixing](85532#startaudiomixing) to set the time interval in AudioMixingConfig to a value greater than 0, the SDK will trigger the callback according to the set time interval.
     */
    onAudioMixingPlayingProgress(mix_id: number, progress: number): void;
    /**
     * @brief SDK  connection state change callback with signaling server. Triggered when the connection state changes.
     * @param state The current connection status between the SDK and the signaling server.
     */
    onConnectionStateChanged(state: ConnectionState): void;
    /**
     * @brief SDK Current network connection type change callback. Callbacks the event when the current network connection type of the SDK changes.
     * @param type The current network connection type
     * @notes Refer to [Getting Connection Status](https://docs.byteplus.com/byteplus-rtc/docs/95376) for more details.
     */
    onNetworkTypeChanged(type: NetworkType): void;
    /**
     * @brief publish performance fallback is not turned on locally. When insufficient device performance is detected, this callback is received. Locally turn on the release performance fallback. When the release performance fallback/recovery is caused due to device performance/network reasons, this callback is received.
     * @param mode Indicates whether the release fallback function is turned on locally.
     * +When the publisher does not turn on the release performance fallback, the mode value is kPerformanceAlarmModeNormal.
     *                   + When the publisher turns on the release performance fallback, the mode value is kPerformance AlarmModeSimulcast.
     * @param room_id + When the release performance fallback is not turned on, the room_id is empty
     * + When the release performance fallback is turned on, the room_id is the room ID affected by the alarm.
     * @param reason Reason for the alarm
     * @param data Performance rollback related data
     */
    onPerformanceAlarms(mode: PerformanceAlarmMode, room_id: string, reason: PerformanceAlarmReason, data: SourceWantedData): void;
    /**
     * @brief  Periodically (2s) issue callbacks to report the current CPU and memory usage
     * @param stats Return the current system state information.
     */
    onSysStats(stats: SysStats): void;
    /**
     * @brief The remote clients in the room will be informed of the state change via this callback after the visible user starts audio capture by calling `startAudioCapture`.
     * @param room_id Room ID
     * @param user_id The user who started the internal audio capture
     */
    onUserStartAudioCapture(room_id: string, user_id: string): void;
    /**
     * @brief The remote clients in the room will be informed of the state change via this callback after the visible user stops audio capture by calling `stopAudioCapture`.
     * @param room_id Room ID
     * @param user_id The user who stopped the internal audio capture
     */
    onUserStopAudioCapture(room_id: string, user_id: string): void;
    /**
     * @brief Receive the callback when the first audio frame is locally collected
     * @param index Audio stream type: audio from microphone or sound card.
     */
    onFirstLocalAudioFrame(index: StreamIndex): void;
    /**
     * @brief This callback informs you when the first frame of every remote audio is received.
     * @param key Remote audio stream information
     */
    onFirstRemoteAudioFrame(key: RemoteStreamKey): void;
    /**
     * @brief Once the Fallback option is set, Fallback or reverting from a Fallback of a media stream will trigger this callback.
     * @param stream Information of stream switching.
     * @notes Call setSubscribeFallbackOption or configure Fallback options on the server side to register this callback.
     */
    onSimulcastSubscribeFallback(stream: RemoteStreamSwitch): void;
    /**
     * @brief RTC SDK receives this callback when the first video frame or screen video frame capture is completed locally.
     * @param index Stream type: video from a camera or the screen recorder
     * @param info Video information
     */
    onFirstLocalVideoFrameCaptured(index: StreamIndex, info: VideoFrameInfo): void;
    /**
     * @brief Receive this callback when the local video size or rotation configuration changes.
     * @param index Stream type: video from a camera or the screen recorder
     * @param info Video frame information
     */
    onLocalVideoSizeChanged(index: StreamIndex, info: VideoFrameInfo): void;
    /**
     * @brief Users in the room who subscribe to this video stream receive this callback when the remote video size or rotation configuration changes.
     * @param key Remote stream information
     * @param stream Video frame information
     */
    onRemoteVideoSizeChanged(key: RemoteStreamKey, stream: VideoFrameInfo): void;
    /**
     * @brief  Receive this callback after the first frame of remote video stream is locally rendered by SDK.
     * @param key Remote stream information
     * @param stream Video frame information
     */
    onFirstRemoteVideoFrameRendered(key: RemoteStreamKey, stream: VideoFrameInfo): void;
    /**
     * @brief Receive this callback after the first frame of remote video stream is received and decoded by SDK.
     * @param key Remote stream information
     * @param stream Video frame information
     */
    onFirstRemoteVideoFrameDecoded(key: RemoteStreamKey, stream: VideoFrameInfo): void;
    /**
     * @brief The remote clients in the room will be informed of the state change via this callback after the visible user starts video capture by calling `startVideoCapture`.
     * @param room_id Room ID
     * @param user_id User who started the video capture.
     */
    onUserStartVideoCapture(room_id: string, user_id: string): void;
    /**
     * @brief The remote clients in the room will be informed of the state change via  this callback after the visible user stops video capture by calling `stopVideoCapture`.
     * @param room_id Room ID
     * @param user_id User who stopped the video capture.
     */
    onUserStopVideoCapture(room_id: string, user_id: string): void;
    /**
     * @brief When the state of the local audio changes, the callback notifies the current local audio state.
     * @param state State of the local audio device
     * @param error Error code when the local audio state changes
     */
    onLocalAudioStateChanged(state: LocalAudioStreamState, error: LocalAudioStreamError): void;
    /**
     * @brief When the state of the audio stream from the remote user subscribes to changes, this callback will be received to understand the current state of the remote audio stream.
     * @param key Remote stream information
     * @param state Remote audio stream state
     * @param reason Reason for remote audio stream state change
     */
    onRemoteAudioStateChanged(key: RemoteStreamKey, state: RemoteAudioState, reason: RemoteAudioStateChangeReason): void;
    /**
     * @brief After calling `enableAudioPropertiesReport`, you will periodically receive this callback for the active speaker information.
     * @param room_id Room ID
     * @param uid The user ID of the active speaker
     */
    onActiveSpeaker(room_id: string, uid: string): void;
    /**
     * @brief Receive this event when the state of the local video stream changes.
     * @param index Stream type: video from a camera or the screen recorder
     * @param state Local video stream status
     * @param error Error code when local video status changes
     */
    onLocalVideoStateChanged(index: StreamIndex, state: LocalVideoStreamState, error: LocalVideoStreamError): void;
    /**
     * @brief When the state of a remote video stream changes, users in the room who subscribe to this stream receive the event.
     * @param key Information about the remote video stream, room, user ID, stream attributes, etc.
     * @param state Remote video stream state
     * @param reason Reason for the remote video stream state change.
     */
    onRemoteVideoStateChanged(key: RemoteStreamKey, state: RemoteVideoState, reason: RemoteVideoStateChangeReason): void;
    /**
     * @brief Audio first frame sending status change callback
     * @param room_id Room ID
     * @param user Local user information
     * @param state First frame sending state
     */
    onAudioFrameSendStateChanged(room_id: string, user: RtcUser, state: FirstFrameSendState): void;
    /**
     * @brief Video first frame sending status change callback
     * @param room_id Room ID
     * @param user Local user information
     * @param state First frame sending state
     */
    onVideoFrameSendStateChanged(room_id: string, user: RtcUser, state: FirstFrameSendState): void;
    /**
     * @brief Screen sharing streaming video first frame sending status change callback
     * @param room_id Room ID
     * @param user Local user information
     * @param state First frame sending state
     */
    onScreenVideoFrameSendStateChanged(room_id: string, user: RtcUser, state: FirstFrameSendState): void;
    /**
     * @brief Screen sharing streaming video first frame sending status change callback
     * @param room_id Room ID
     * @param user Local user information
     * @param state First frame playback state
     */
    onAudioFramePlayStateChanged(room_id: string, user: RtcUser, state: FirstFramePlayState): void;
    /**
     * @brief  Video first frame playback state change callback
     * @param room_id Room ID
     * @param user Local user information
     * @param state First frame playback state
     */
    onVideoFramePlayStateChanged(room_id: string, user: RtcUser, state: FirstFramePlayState): void;
    /**
     * @brief Screen sharing streaming video first frame playback state change callback
     * @param room_id Room ID
     * @param user Local user information
     * @param state First frame playback state
     */
    onScreenVideoFramePlayStateChanged(room_id: string, user: RtcUser, state: FirstFramePlayState): void;
    /**
     * @brief After sending a text or binary message (P2P) to a single user in the room, the message sender receives a callback with the result of the message.
     * @param msgid ID of this message.
     * @param error Text or binary message sending results.
     */
    onUserMessageSendResult(msgid: number, error: MessageSendResultCode): void;
    /**
     * @brief Receive this callback when you receive a binary message from an out-of-room user calling `sendUserBinaryMessage`.
     * @param uid User ID of the message sender
     * @param message Content of the message
     */
    onUserBinaryMessageReceived(uid: string, message: string): void;
    /**
     * @brief Callback on subscription status of media streams
     * @param state_code Subscription status of media streams
     * @param user_id The ID of the user who published the stream.
     * @param info Configurations of stream subscription
     */
    onStreamSubscribed(state_code: SubscribeState, user_id: string, info: SubscribeConfig): void;
    /**
     * @brief Receive this callback when you receive a video frame with a SEI message sent via sendSEIMessage
     * @param stream_key Contains the user name, room name and media stream of the SEI sender.
     * @param message The content of the SEI message received
     */
    onSEIMessageReceived(stream_key: RemoteStreamKey, message: string): void;
    /**
     * @brief Used for reporting events during pushing streams to CDN
     * @param event Type Stream mixing status
     * @param task_id Task ID
     * @param error Errors occuring during the pushing process.
     * + `0`: Successfully pushed streams to target CDN.
     * + `1090`: Undefined error
     * + `1091`: Invalid parameters detected by Client SDK
     * + `1092`: Program runs with an error, the state machine is in abnormal condition.
     * + `1093`: Invalid operation
     * + `1094`: Request timed out. Please check network status and retry.
     * + `1095`: Invalid parameters detected by the server
     * + `1096`: Subscription to the stream has expired.
     * + `1097`: Internal server error.
     * + `1098`: The server failed to push streams to CDN.
     * + `1099`: Signaling connection timeout error. Please check network status and retry.
     * + `1100`: Failed to mix image.
     * + `1101`: Unknown error from server.
     * @param mix_type Stream mixing and pushing type
     */
    onStreamMixingEvent(event: StreamMixingEvent, task_id: string, error: number, mix_type: StreamMixingType): void;
    /**
     * @brief Used for reporting events during pushing a single stream to CDN.
     * @param event Stream mixing and pushing status
     * @param task_id Task ID
     * @param error Errors occuring during the pushing process.
     * + `0`: Successfully pushed streams to target CDN.
     * + `1090`: Undefined error
     * + `1091`: Invalid parameters detected by Client SDK
     * + `1092`: Program runs with an error, the state machine is in abnormal condition.
     * + `1093`: Invalid operation
     * + `1094`: Request timed out. Please check network status and retry.
     * + `1095`: Invalid parameters detected by the server
     * + `1096`: Subscription to the stream has expired.
     * + `1097`: Internal server error.
     * + `1098`: The server failed to push streams to CDN.
     * + `1099`: Signaling connection timeout error. Please check network status and retry.
     * + `1100`: Failed to mix image.
     * + `1101`: Unknown error from server.
     */
    onStreamPushEvent(event: SingleStreamPushEvent, task_id: string, error: number): void;
    /**
     * @brief Callback of the local recording status.
     * @param type Stream properties of the recorded stream.
     * @param state Recording state
     * @param error_code Recording error code
     * @param info For more information about the recorded file.
     * @notes The callback is triggered by  [startFileRecording](85532#StartFileRecording) or [stopFileRecording](85532#stopFileRecording) .
     */
    onRecordingStateUpdate(type: StreamIndex, state: number, error_code: number, info: RecordingInfo): void;
    /**
     * @brief Local recording progress callback.
     * @param type Stream properties of the recorded stream
     * @param process Recording progress
     * @param info More information about the recorded file
     * @notes This callback is triggered by [startFileRecording](85532#StartFileRecording). When the recording state is normal, the system will prompt the recording progress through this callback every second.
     */
    onRecordingProgressUpdate(type: StreamIndex, process: RecordingProgress, info: RecordingInfo): void;
    /**
     * @brief login result callback
     * @param uid Login user ID
     * @param error_code Login result
     * @param elapsed The time taken from the call to [login](85532#login) to the receipt of the result. Measured by ms.
     */
    onLoginResult(uid: string, error_code: number, elapsed: number): void;
    /**
     * @brief logout result callback
     * @notes After calling [logout](85532#Logout), you will receive this callback.
     */
    onLogout(): void;
    /**
     * @brief Set the return result of the application server parameter
     * @param error
     * + 200, set successfully
     * + != 200: Failure.
     * @notes Receive this callback after calling [setServerParams](85532#setserverparams).
     */
    onServerParamsSetResult(error: number): void;
    /**
     * @brief Callback to tell the login state of a user.
     * @param peer_user_id User ID
     * @param status Login status of the user
     * @notes Call [getPeeronlineStatus](85532#getpeeronlinestatus) before you can get this callback.
     */
    onGetPeerOnlineStatus(peer_user_id: string, status: number): void;
    /**
     * @brief Receive this callback when you receive a text message from an out-of-room user calling sendUserMessageOutsideRoom.
     * @param uid User ID of the message sender
     * @param message Received text message content
     */
    onUserMessageReceivedOutsideRoom(uid: string, message: string): void;
    /**
     * @brief Receive this callback when you receive a binary message from an out-of-room user calling `sendUserBinaryMessageOutsideRoom`.
     * @param uid User ID of the message sender
     * @param message Binary message content received
     */
    onUserBinaryMessageReceivedOutsideRoom(uid: string, message: string): void;
    /**
     * @brief A callback that sends a message to a specified user outside the room
     * @param msgid The ID of this message. All P2P and P2Server messages share a single ID sequence.
     * @param error Message sending result
     * @notes Receive this callback when a message is sent by calling [sendUserMessageOutsideRoom](85532#sendusermessageoutsideroom) or [sendUserBinaryMessageOutsideRoom](#senduserbinarymessageoutsideroom).
     */
    onUserMessageSendResultOutsideRoom(msgid: number, error: number): void;
    /**
     * @brief Callback to send a message to the application server
     * @param msgid The ID of this message
     *        All P2P and P2Server messages share a single ID sequence.
     * @param error Message Sending Results.
     * @param message The message returned in ACK when the application server receives HTTP request.
     * @notes Receive this callback when you call [sendServerMessage](85532#sendservermessage) or [sendServerBinaryMessage](85532#sendserverbinarymessage) to send a message to your application server.
     */
    onServerMessageSendResult(msgid: number, error: number, message: string): void;
    /**
     * @brief Returns audio data recorded by microphone
     * @param audio_frame Audio data
     */
    onRecordAudioFrame(audio_frame: IAudioFrame): void;
    /**
     * @brief Returns the mixed audio data of all subscribed remote users
     * @param audio_frame Audio data
     */
    onPlaybackAudioFrame(audio_frame: IAudioFrame): void;
    /**
     * @brief Returns mixed audio data including both data recorded by the local microphone and data from all subscribed remote users
     * @param audio_frame Audio data
     */
    onMixedAudioFrame(audio_frame: IAudioFrame): void;
    /**
     * @brief Speech recognition service started successfully.
     */
    onASRSuccess(): void;
    /**
     * @brief The voice-to-text callback is successful, and the callback returns the full amount of messages after recognition.
     * @param message Text message obtained after the completion of the recognition
     * @notes If the network connection is interrupted during the recognition process, the callback information after the reconnection contains only the text message recognized after the reconnection, and no longer contains the last connection. The message identified after.
     */
    onMessage(message: string): void;
    /**
     * @brief This callback is triggered when an error event occurs within the speech recognition service.
     * @param error_code Error code
     * + < 0: parameter error or API call order error.
     * + `-1`: Disconnected. SDK will keep retrying.
     * + `-2`: Call startASR repeatdely. Call stopASR when you intend to start ASR service again.
     * + `-3`: Token of ASR service is required.
     * + `-4`: secret_key is required in the Signature mode.
     * + `-5`: User ID is required.
     * + `-6`: App ID is required.
     * + `-7`: cluster is required.
     * + `-8`: Connection building error. Please contact our technical specialist for the correct SDK version with ASR service.
     * @param error_message Detailed error message
     */
    onASRError(error_code: number, error_message: string): void;
    /**
     * @brief Pre-call network detection result.
     * @param type Identifies the network type as uplink/downlink.
     * @param quality Network quality
     * @param rtt Network RTT in ms
     * @param lost_rate Packet loss rate
     * @param bit_rate Network bandwidth in kbps
     * @param jitter Network jitter in ms
     * @notes After successfully calling [startNetworkDetection](#startnetworkdetection), you will receive this callback for the first time in 3s and every 2s thereafter.
     */
    onNetworkDetectionResult(type: number, quality: number, rtt: number, lost_rate: number, bit_rate: number, jitter: number): void;
    /**
     * @brief Pre-call network probing ends
     * @param reason Reason of stopping probing
     * @notes The following will stop detection and receive this primary callback:
     *        1. This callback is received once when the [stopNetworkDetection](#stopnetworkdetection) interface is called to stop probing;
     *        2. Stop detection when the first frame of remote/local audio is received;
     *        3. Stop detecting when the detection exceeds 3 minutes;
     *        4. When the probe link is disconnected for a certain period of time, the probe is stopped.
     */
    onNetworkDetectionStopped(reason: number): void;
    /**
     * @brief After calling `enableAudioPropertiesReport`, you will periodically receive this callback for the information about local audio.
     * @param audio_properties_infos Local audio which includes the microphone audio and the screen audio captured using RTC SDK internal mechanisms.
     * @param audio_properties_info_number length of the array which you can ignore.
     */
    onLocalAudioPropertiesReport(audio_properties_infos: LocalAudioPropertiesInfo, audio_properties_info_number: number): void;
    /**
     * @brief Notification on the playing volume during the test for the local audio devices
     * @param audio_properties_infos Remote audio properties including audio from a microphone or the soudn card.
     * @param audio_properties_info_number length of the array which you can ignore
     * @param total_remote_volume playing volume during the test for the local audio devices in milliseconds. We recommend to set it to 200 ms.The range is [0,255].
     */
    onRemoteAudioPropertiesReport(audio_properties_infos: RemoteAudioPropertiesInfo, audio_properties_info_number: number, total_remote_volume: number): void;
    /**
     * @brief Callback about the call test result.
     * @param result + kTestSuccess	0:	Success
     * + kTestTimeout 1:	Abort after a 60 sec timeout
     * + kTestIntervalShort 2:	The next test must start 5 sec after the end the previous test.
     * + kAudioDeviceError	3:	Error in audio capture
     * + kVideoDeviceError	4:	Error in video capture
     * + kAudioReceiveError	5:	Error in receiving audio
     * + kVideoReceiveError	6:	Error in receiving video
     * + kInternalError	7:	Unrecoverable error
     * @notes The timing when this callback will be triggered is as follows:
     * + A device-related error occured during the test；
     * + After a successful test；
     * + After stopping the test, provided that the audio/video playback was not received during the test due to non-device reasons.
     */
    onEchoTestResult(result: EchoTestResult): void;
    /**
     * @brief Callback of video device state. Video devices include cameras and screen sharing video capture devices.
     * @param device_id Device ID
     * @param device_type Device type
     * + `-1`: Unknown
     * + `0`: Video rendering device
     * + `1`: Video capture device
     * + `2`: Screen recorder
     * @param device_state Device state
     * + `1`: On
     * + `2`: Off
     * + `3`: Runtime error, for example, when the media device is expected to be working but no data is received.
     * + `4`: Device paused. Including:
     *         + During screen capturing, the target application window is minimized in the taskbar.
     *         + Before or during screen capturing, the target application window is hidden.
     *         + During screen capturing, the target application window is being stretched.
     *         + During screen capturing, the target application window is being dragged.
     * + `5`: Resumed.
     * + `10`: Added.
     * + `11`: Removed.
     * + `12`: Closing the laptop interrupted the RTC call. RTC call will resume once the laptop is opened.
     * + `13`: RTC call resumed from the interruption caused by Closing the laptop.
     * + `14`: The device just became the default device.
     * + `15`: The device is no longer the default device.
     * @param device_error Device error
     * + `0`: Media equipment is normal.
     * + `1`: No permission to start media device
     * + `2`: Media devices are already in use
     * + `3`: Media device error
     * + `4`: The specified media device was not found.
     * + `5`: Media device, window or monitor removed.
     * + `6`: Device has no data callback.
     * + `7`: Device sample rate not supported.
     */
    onVideoDeviceStateChanged(device_id: string, device_type: number, device_state: number, device_error: number): void;
    /**
     * @brief Callback of video device state. Video devices include cameras and screen sharing video capture devices.
     * @param device_id Device ID
     * + `-1`: Unknown device
     * + `0`: Video rendering device
     * + `1`: Video capture device
     * + `2`: Screen recorder
     * @param device_type Device type
     * + `1`: On
     * + `2`: Off
     * + `3`: Runtime error. For example, when the media device is expected to be working but no data is received.
     * + `4`: Device paused. Including:
     * + During screen capturing, the target application window is minimized in the taskbar.
     * + Before or during screen capturing, the target application window is hidden.
     * + During screen capturing, the target application window is being stretched.
     * + During screen capturing, the target application window is being dragged. <
     * + `5`: Device resumed
     * + `10`: Added
     * + `11`: Removed
     * + `12`: Closing the laptop interrupted the RTC call. RTC call will resume once the laptop is opened.
     * + `13`: RTC call resumed from the interruption caused by Closing the laptop.
     * + `14`: The device just became the default device.
     * + `15`: The device is no longer the default device.
     * @param device_state Device state
     * + `0`: Media equipment is normal
     * + `1`: No permission to start media device
     * + `2`: Media devices are already in use
     * + `3`: Media device error
     * + `4`: The specified media device was not found.
     * + `5`: Media device, window or monitor removed.
     * + `6`: Device has no data callback.
     * + `7`: Device sample rate not supported.
     * @param device_error Device error
     */
    onAudioDeviceStateChanged(device_id: string, device_type: number, device_state: number, device_error: number): void;
    /**
     * @brief Notification on the playing volume during the test for the local audio devices
     * @param volume Playing volume during the test for the local audio devices in milliseconds. We recommend to set it to 200 ms. The range is [0,255].
     * @notes Start an audio-device test by calling [startAudioPlaybackDeviceTest](#startaudioplaybackdevicetest) will register this callback for regular notification on playing volume. You can set the time interval between each callback by passing a proper value when calling the API above.
     */
    onAudioPlaybackDeviceTestVolume(volume: number): void;
    /**
     * @brief Terminal monitoring log callback. The callback is triggered when a terminal monitoring event is generated.
     * @param log_type Event type. For now, "live_webrtc_monitor_log" is the only one available value.
     * @param log_content Terminal monitoring log content
     */
    onLogReport: (log_type: string, log_content: string) => void;
}
