/**
 * @brief Video rendering scale mode
 */
export declare enum RenderMode {
    /**
     * @brief Fit.
     *        The video frame is scaled with fixed aspect ratio, until it fits just within the canvas. Other part of the canvas is filled with the background color.
     */
    FIT = 1,
    /**
     * @brief Fill and Crop.
     *        The video frame is scaled with fixed aspect ratio, until it completely fills the canvas. The region of the video exceeding the canvas will be cropped.
     */
    HIDDEN = 2
}
/**
 * @brief Render options
 */
export interface RenderOptions {
    /**
     * @brief Scale mode when rendering
     */
    render_mode: RenderMode;
    /**
     * @brief Whether to turn on mirror mode
     */
    mirror: boolean;
}
/**
 * @brief Subscription status of media streams
 */
export declare enum SubscribeState {
    /**
     * @brief Successfully changed the subscription status
     */
    kSubscribeStateSuccess = 0,
    /**
     * @brief Failed to change the subscription status, because you were not in the room.
     */
    kSubscribeStateFailedNotInRoom = 1,
    /**
     * @brief Failed to change the subscription status, because the target audio/video stream was not found.
     */
    kSubscribeStateFailedStreamNotFound = 2,
    /**
     * @brief Failed to change the subscription status, because the number of streams you have subscribed to has exceeded the limit.
     */
    kSubscribeStateFailedOverLimit = 3
}
/**
 * @brief Configuration information for manual subscription flows.
 */
export interface SubscribeConfig {
    /**
     * @brief Whether it is a screen stream (default is no).
     */
    is_screen: boolean;
    /**
     * @brief Whether to subscribe to videos.
     */
    sub_video: boolean;
    /**
     * @brief Whether to subscribe to audio.
     */
    sub_audio: boolean;
    /**
     * @brief Subscribed video stream resolution subscript.
     *        Users can publish multiple videos of different resolutions in a stream by calling the [setVideoEncoderConfig](85532#setvideoencoderconfig) method. Therefore, when subscribing to a stream, you need to specify the specific resolution of the subscription. This parameter is used to specify the subscript of the resolution to be subscribed to, and the default value is 0.
     */
    video_index: number;
    /**
     * @brief For the remote user's requirement priority. It defaults to 0, meaning the lowest priority.
     * + `100`: Normal
     * + `200`: High priory
     *         When the subscription flow fallback option function is turned on (see [setSubscribeFallbackOption](85532#setsubscribefallbackoption) method for details), weak connections or insufficient performance will give priority to ensuring the quality of the received high-priority user's flow.
     */
    priority: number;
    /**
     * @brief The time domain hierarchy of the remote user. It defaults to 0
     *         This only works if the stream supports the SVC feature.
     */
    svc_layer: number;
    /**
     * @brief Expected maximum frame rate of the subscribed stream in px. The default value is 0, values greater than 10 are valid.
     *        If the frame rate of the stream published is lower than the value you set, or if your subscribed stream falls back under limited network conditions, the frame rate you set will drop accordingly.
     *        Only valid if the stream is coded with SVC technique.
     */
    framerate: number;
    /**
     * @brief The user specifies the width(px) of the most appropriate stream corresponding to the UI by specifying
     */
    sub_width: number;
    /**
     * @brief The user specifies the height(px) of the most appropriate stream corresponding to the UI by specifying
     */
    sub_height: number;
    /**
     * @hidden
     */
    sub_video_index: number;
}
/**
 * @brief Coordinates of the screen-sharing object.
 * +When there are several screens, the origin (0, 0) is different for different platforms:
 *         - For Windows, the origin (0, 0) is the top-left corner of the main screen.
 *         - For Linux, the origin (0, 0) is the top-left corner of the rectangle that merely covers all screens.
 * +The region of the window is different for different platforms:
 *         - For Windows and macOS, the region includes the system title bar of the window.
 *         - For Linux, the region does not includes the system title bar of the window.
 */
export interface Rectangle {
    /**
     * @brief The x coordinate of the upper left corner of the rectangular area
     */
    x: number;
    /**
     * @brief The y coordinate of the upper left corner of the rectangular area
     */
    y: number;
    /**
     * @brief Rectangle width
     */
    width: number;
    /**
     * @brief Rectangular height
     */
    height: number;
}
/**
 * @brief Border highlighting settings for screen sharing
 */
export interface HighlightConfig {
    /**
     * @brief Whether to display a highlighted border. Yes by default.
     */
    enable_highlight: boolean;
    /**
     * @brief The color of the border in hexadecimal ARGB: 0xAARRGGBB. It defaults to 0xFF29CCA3.
     */
    border_color: number;
    /**
     * @brief The width of the border in pixel. It defaults to 4.
     */
    border_width: number;
}
/**
 * @brief  Video frame scale mode
 */
export declare enum ScaleMode {
    /**
     * @brief Auto mode, default to FitWithCropping.
     */
    Auto = 0,
    /**
     * @brief Stretch the video frame until the video frame and the window have the same resolution. The video frame's aspect ratio can be changed as it is automatically stretched to fill the window, but the whole image is visible.
     */
    Stretch = 1,
    /**
     * @brief  Fit the window with cropping
     *         Scale the video frame uniformly until the window is filled. If the video frame's aspect ratio is different from that of the window, the extra part of the video frame will be cropped.
     *         After the scaling process is completed, the width or height of the video frame will be consistent with that of the window, and the other dimension will be greater than or equal to that of the window.
     */
    FitWithCropping = 2,
    /**
     * @brief  Fit the window with filling
     *         Scale the video frame uniformly until its width or height reaches the boundary of the window. If the video frame's aspect ratio is different from that of the window, the area that is not filled will be black.
     *         After the scaling process is completed, the width or height of the video frame will be consistent with that of the window, and the other dimension will be less than or equal to that of the window.
     */
    FitWithFilling = 3
}
/**
 * @brief Video encoder type
 */
export declare enum VideoCodecType {
    /**
     * @brief Unknown
     */
    kVideoCodecUnknown = 0,
    /**
     * @brief H264
     */
    kVideoCodecH264 = 1,
    /**
     * @hidden
     * @brief
     */
    kVideoCodecByteVC1 = 2
}
/**
 * @brief  Video encoding mode
 */
export declare enum CodecMode {
    /**
     * @brief Automatic
     */
    AutoMode = 0,
    /**
     * @brief Hardware encoding
     */
    HardwareMode = 1,
    /**
     * @brief Software encoding
     */
    SoftwareMode = 2
}
/**
 * @brief Auto
 */
export declare const SEND_KBPS_AUTO_CALCULATE = -1;
/**
 * @brief Disable
 */
export declare const SEND_KBPS_DISABLE_VIDEO_SEND = 0;
/**
 * @brief Video encoding configuration. Refer to [Setting Video Encoder Configuration](https://docs.byteplus.com/byteplus-rtc/docs/70122) to learn more.
 */
export interface VideoEncoderConfig {
    /**
     * @brief Width of the video frame in px
     */
    width: number;
    /**
     * @brief Height of the video frame in px
     */
    height: number;
    /**
     * @brief Video frame rate in fps
     */
    frameRate: number;
    /**
     * @brief Maximum bit rate in kbps. Optional for internal capturing while mandatory for custom capturing.
     *        The default value is -1 in internal capturing mode, SDK will automatically calculate the applicable bit rate based on the input resolution and frame rate.
     *        No stream will be encoded and published if you set this parameter to 0.
     */
    maxBitrate: number;
    /**
     * @brief Encoding policy preference. The default policy is quality first.
     */
    encoderPreference: VideoEncodePreference;
}
/**
 * @brief Call related statistics
 */
export interface RtcRoomStats {
    /**
     * @brief Current Tx packet loss rate. The range is [0,1].
     */
    txLostrate: number;
    /**
     * @brief Current Rx packet loss rate. The range is [0,1].
     */
    rxLostrate: number;
    /**
     * @brief Round-trip time (in ms) from client side to server side
     */
    rtt: number;
    /**
     * @brief Cumulative time between the user joining the room and leaving the room in seconds.
     */
    duration: number;
    /**
     * @brief Cumulative data sent by the user in bytes.
     */
    tx_bytes: number;
    /**
     * @brief Cumulative data received by the user in bytes.
     */
    rx_bytes: number;
    /**
     * @brief The instantaneous value of Tx bitrate in kbps
     */
    tx_kbitrate: number;
    /**
     * @brief The instantaneous value of Rx bitrate in kbps
     */
    rx_kbitrate: number;
    /**
     * @brief The instantaneous value of audio Rx bitrate in kbps
     */
    rx_audio_kbitrate: number;
    /**
     * @brief The instantaneous value of audio Tx bitrate in kbps
     */
    tx_audio_kbitrate: number;
    /**
     * @brief The instantaneous value of video Rx bitrate in kbps
     */
    rx_video_kbitrate: number;
    /**
     * @brief The instantaneous value of video Tx bitrate in kbps
     */
    tx_video_kbitrate: number;
    /**
     * @brief The instantaneous RX bitrate of screen-sharing video in Kbps
     */
    rx_screen_kbitrate: number;
    /**
     * @brief The instantaneous TX bitrate of screen-sharing video in Kbps
     */
    tx_screen_kbitrate: number;
    /**
     * @brief Number of visible users in the current room
     */
    user_count: number;
    /**
     * @hidden
     * @brief CPU usage (%) of the application
     */
    cpu_app_usage: number;
    /**
     * @hidden
     * @brief Current CPU usage (%)
     */
    cpu_total_usage: number;
    /**
     * @brief Tx jitter(ms)
     */
    tx_jitter: number;
    /**
     * @brief Rx jitter(ms)
     */
    rx_jitter: number;
    /**
     * @brief Cellular Link Send bit rate  (kbps), get the instantaneous value of the data
     */
    tx_cellular_kbitrate: number;
    /**
     * @brief Cellular Link Receive bit rate  (kbps), get the instantaneous value of the data
     */
    rx_cellular_kbitrate: number;
}
/**
 * @brief Sets the video frame
 */
export interface IVideoFrame {
    /**
     * @brief Room ID
     */
    channel_id: string;
    /**
     * @brief User ID
     */
    user_id: string;
    /**
     * @brief Video data buffer in plane Y
     */
    plane_y: Uint8Array;
    /**
     * @brief Video data buffer in plane U
     */
    plane_u: Uint8Array;
    /**
     * @brief Video data buffer in plane V
     */
    plane_v: Uint8Array;
    /**
     * @brief Pixel of the width of the video
     */
    width: number;
    /**
     * @brief Pixel of the height of the video
     */
    height: number;
    /**
     * @brief Size of Plane Y of the video data buffer
     */
    plane_size_y: number;
    /**
     * @brief Size of Plane U of the video data buffer
     */
    plane_size_u: number;
    /**
     * @brief Size of Plane V of the video data buffer
     */
    plane_size_v: number;
    /**
     * @brief Format of the video frames
     */
    format: number;
    /**
     * @brief Rotation angles of the video frame
     */
    rotation: number;
    public_stream_id: number;
}
/**
 * @brief Audio frame
 */
export interface IAudioFrame {
    /**
     * @brief Audio frame type
     */
    type: AudioFrameType;
    /**
     * @brief Audio channel.
     *        For dual channels, the audio frames are interleaved.
     */
    channels: number;
    /**
     * @brief Sample rate.
     */
    sample_rate: number;
    /**
     * @brief Address of the audio data buffer
     */
    buffer: Uint8Array;
    /**
     * @brief Audio frame timestamp in milliseconds
     */
    render_time_ms: number;
    mute: boolean;
}
/**
 * @brief Audio frame type
 */
export declare enum AudioFrameType {
    /**
     * @brief PCM 16bit
     */
    kFrameTypePCM16 = 0
}
export declare enum AudioChannel {
    kAudioChannelAuto = -1,
    kAudioChannelMono = 1,
    kAudioChannelStereo = 2
}
export declare enum AudioSampleRate {
    kAudioSampleRateAuto = -1,
    kAudioSampleRate8000 = 8000,
    kAudioSampleRate16000 = 16000,
    kAudioSampleRate32000 = 32000,
    kAudioSampleRate44100 = 44100,
    kAudioSampleRate48000 = 48000
}
/**
 * @brief SDK  Connection status with the signaling server.
 */
export declare enum ConnectionState {
    /**
     * @brief Disconnected for 12s, SDK will try to reconnect automatically.
     */
    kConnectionStateDisconnected = 1,
    /**
     * @brief The first request to connect to the server. Connecting.
     */
    kConnectionStateConnecting = 2,
    /**
     * @brief The first connection was successful.
     */
    kConnectionStateConnected = 3,
    /**
     * @brief The code includes the following status:
     *        + The first connection is not successful for 10s.
     *        + The connection has been lost for 10s. Auto reconnecting.
     */
    kConnectionStateReconnecting = 4,
    /**
     * @brief Successful reconnection after disconnection.
     */
    kConnectionStateReconnected = 5,
    /**
     * @brief In status `kConnectionStateDisconnected` for more than 10s without a successful reconnection. SDK will still continue to try to reconnect.
     */
    kConnectionStateLost = 6
}
/**
 * @brief Reason to leave the room
 */
export declare enum UserOfflineReasonType {
    /**
     * @brief The remote client calls [leaveRoom](85532#leaveroom) to leave the room.
     */
    kUserOfflineReasonQuit = 0,
    /**
     * @brief The remote client is disconnected because of poor network connection or expired Token.
     */
    kUserOfflineReasonDropped = 1,
    /**
     * @brief The remote client calls [setUserVisibility](#rtcroom#setuservisibility) to turn invisible.
     */
    kUserOfflineReasonSwitchToInvisible = 2,
    /**
     * @brief The remote user has been removed from the room by the administrator via a OpenAPI call.
     */
    kUserOfflineReasonKickedByAdmin = 3
}
export declare enum MediaDeviceType {
    kMediaDeviceTypeAudioRenderDevice = 0,
    kMediaDeviceTypeAudioCaptureDevice = 1,
    kMediaDeviceTypeVideoRenderDevice = 2,
    kMediaDeviceTypeVideoCaptureDevice = 3
}
export declare enum MediaDeviceNotification {
    kMediaDeviceNotificationActive = 1,
    kMediaDeviceNotificationDisabled = 2,
    kMediaDeviceNotificationNotPresent = 4,
    kMediaDeviceNotificationUnplugged = 8
}
/**
 * @brief Type of the screen capture object
 */
export declare enum ScreenCaptureSourceType {
    /**
     * @brief Type unknown
     */
    kScreenCaptureSourceTypeUnknown = 0,
    /**
     * @brief Application window
     */
    kScreenCaptureSourceTypeWindow = 1,
    /**
     * @brief Desktop
     */
    kScreenCaptureSourceTypeScreen = 2
}
/**
 * @brief Priority of the publisher. When a user encounters performance insufficiency of either the network or the device, the media stream  will fall back in the ascending order of `RemoteUserPriority`.
 */
export declare enum RemoteUserPriority {
    /**
     * @brief Low, the default
     */
    kRemoteUserPriorityLow = 0,
    /**
     * @brief Medium
     */
    kRemoteUserPriorityMedium = 100,
    /**
     * @brief High
     */
    kRemoteUserPriorityHigh = 200
}
/**
 * @brief Detailed information of the screen sharing object
 * Parameter type of the [startScreenVideoCapture](85532#startscreenvideocapture)
 */
export interface ScreenCaptureSourceInfo {
    /**
     * @brief Type of the screen-sharing object.
     */
    type: ScreenCaptureSourceType;
    /**
     * @brief ID of the screen-sharing object
     */
    source_id: number;
    /**
     * @brief Name of the screen-sharing object
     */
    source_name: string;
    /**
     * @brief The title of the application to be shared.
     *        Only available if the sharing object is an application windows.
     */
    application: string;
    /**
     * @brief Tag for the screen to be shared identifying whether it is the primary screen
     *        Only available when the screen-sharing object is a screen.
     */
    primaryMonitor: boolean;
    /**
     * @brief The x coordinate of the upper left corner of the rectangular area
     * Coordinates of the screen-sharing object.
     * + When there are several screens, the origin (0, 0) is different for different platforms:
     *         - For Windows, the origin (0, 0) is the top-left corner of the main screen.
     *         - For Linux, the origin (0, 0) is the top-left corner of the rectangle that merely covers all screens.
     * + The region of the window is different for different platforms:
     *         - For Windows and macOS, the region includes the system title bar of the window.
     *         - For Linux, the region does not includes the system title bar of the window.
     */
    x: number;
    /**
     * @brief The y coordinate of the upper left corner of the rectangular area
     */
    y: number;
    /**
     * @brief Width of the rectangle area to be shared
     */
    width: number;
    /**
     * @brief Height of the rectangular area to be shared
     */
    height: number;
    /**
     * @brief Process pid of the application to be shared.
     *        Only available if the sharing object is an application windows.
     */
    pid: number;
    /**
     * @brief 屏幕共享对象的坐标。多显示器的场景下，屏幕坐标系统以主屏左上角为原点 (0, 0)，向右向下扩展。详见 Rectangle{@link #Rectangle}。
     */
    region_rect: Rectangle;
}
export interface ThumbnailInfo {
    width: number;
    height: number;
    data: string;
}
export interface AppIconInfo {
    width: number;
    height: number;
    data: string;
}
/**
 * @brief Properties of the public audio stream
 */
export interface PublicStreamAudioParam {
    /**
     * @brief Required. Audio sample rate in Hz. Options: 16000, 32000, 44100, or 48000
     */
    sample_rate: number;
    /**
     * @brief Required. Number of the audio channels.
     * + 1: Mono
     * + 2: Dual
     */
    channel_num: number;
    bitrate_kbps: number;
}
/**
 * @brief Encoding properties of the public video stream
 */
export interface PublicStreamVideoParam {
    /**
     * @brief Required. Width of the video frame. Unit: px. Ranging: [16, 1920], even value is effective.
     */
    width: number;
    /**
     * @brief Required. Width of the video frame. Unit: px. Ranging: [16, 1280], even value is effective.
     */
    height: number;
    /**
     * @brief Required. Frame rate in fps
     *        Range: [1, 60]
     */
    fps: number;
    /**
     * @brief Required. Bitrate in bps
     *        Range: [1,10000000]
     */
    bitrate_kpbs: number;
}
/**
 * @brief Rendering mode
 */
export declare enum PublicStreamRenderMode {
    /**
     * @brief Fill and Crop.
     *        The video frame is scaled with fixed aspect ratio, and completely fills the canvas. The region of the video exceeding the canvas will be cropped.
     */
    kRenderModeHidden = 1,
    /**
     * @brief Fit.
     *        The video frame is scaled with fixed aspect ratio, and is shown completely in the canvas. The region of the canvas not filled with video frame, is filled with `background`.
     */
    kRenderModeFit = 2,
    /**
     *  @brief Fill the canvas.
     *         The video frame is scaled to fill the canvas. During the process, the aspect ratio may change.
     */
    kRenderModeFill = 3
}
/**
 * @brief Configurations on how to crop the public stream
 */
export interface SourceCrop {
    /**
     * @brief The normalized horizontal coordinate value of the top left vertex of the cropped image to width of the original image, ranging within [0.0, 1.0).
     */
    LocationX: number;
    /**
     * @brief The normalized vertical coordinate value of the top left vertex of the cropped image to height of the original image, ranging within [0.0, 1.0).
     */
    LocationY: number;
    /**
     * @brief The normalized ratio of the width of the cropped image to that of the original image, ranging within [0.0, 1.0).
     */
    WidthProportion: number;
    /**
     * @brief The normalized ratio of the height of the cropped image to that of the original image, ranging within [0.0, 1.0).
     */
    HeightProportion: number;
}
/**
 * @brief Layout of each stream to be mixed into the public stream
 *        You can configure each of the video streams for the public stream.
 */
export interface PublicStreamLayoutRegion {
    /**
     * @brief ID of the public stream，must not be empty
     */
    user_id: string;
    /**
     * @brief ID of the room from which the stream is intended to be sent as a public stream，
     * must not be empty
     */
    room_id: string;
    /**
     * @brief Uniform resource identifier(URI) of the background image
     */
    alternate_image_uri: string;
    /**
     * @brief Required. Left offset of the video against the local client' view, ranging [0.0, 1.0)
     */
    x: number;
    /**
     * @brief Required. Top offset of the video against the local client' view, ranging [0.0, 1.0)
     */
    y: number;
    /**
     * @brief Required. Ratio of the width of the video to that of the client's view, ranging [0.0, 1.0)
     */
    width: number;
    /**
     * @brief Required. Ratio of the height of the video to that of the client's view, ranging [0.0, 1.0)
     */
    height: number;
    /**
     * @brief Transparency, ranging [0，255], 0 for transparent. 255 for solid.
     */
    alpha: number;
    /**
     * @brief Stack's layer order (also known as the z-order) of videos in the public stream.
     *        Ranging [0, 100]. 0 for the bottom, by default. 100 for the top.
     */
    z_order: number;
    /**
     * @brief Required. Stream index:
     *        + 0: Main stream which is video or audio stream captured by media device or externally sourced media stream.
     *        + 1: Screen-sharing stream
     */
    stream_type: number;
    /**
     * @brief Media type of the public stream.
     */
    media_type: TranscoderContentControlType;
    /**
     * @brief Required. The fit mode when rendering.
     */
    render_mode: PublicStreamRenderMode;
    /**
     * @brief Configurations on how to crop the public stream.
     */
    source_crop: SourceCrop;
}
/**
 * @brief State and errors for publishing or subscribing public streams
 */
export declare enum PublicStreamErrorCode {
    /**
     * @brief Published or subscribed successfully.
     */
    kPublicStreamOK = 0,
    /**
     * @brief Invalid parameter(s). Please revise the paramter(s) and retry.
     */
    kPublicStreamPushInvalidParam = 1191,
    /**
     * @brief Error for the task at the server side. The server will retry automatically.
     */
    kPublicStreamPushInvalidStatus = 1192,
    /**
     * @brief Unrecoverable error of publishing the public stream. Please start the task again.
     */
    kPublicStreamPushInternalError = 1193,
    /**
     * @brief Failed to publish the public stream. The SDK  will retry that you have no need to handle.
     */
    kPublicStreamPushFailed = 1195,
    /**
     * @brief Time-out error of publishing the public stream. The SDK will retry in 10 s. The SDK will stop trying again after three times of failures.
     */
    kPublicStreamPushTimeout = 1196
}
/**
 * @brief Properties of the public stream
 */
export interface IPublicStreamParam {
    /**
     * @brief Interpolation mode of the public stream.
     *         + `0`: Insert with the last frame
     *         + `1`: Insert with the background image. RTC will insert frames of black if no background image has been set.
     */
    mode: number;
    /**
     * @brief Confluence room ID
     */
    room_id: string;
    /**
     * @brief The URI of the background image
     */
    background_image_uri: string;
    /**
     * @brief Properties of the public audio stream.
     */
    audio_param: PublicStreamAudioParam;
    /**
     * @brief Properties of the public video stream.
     */
    video_param: PublicStreamVideoParam;
    /**
     * @brief Layout of the region in the public stream.
     */
    layout_regions: PublicStreamLayoutRegion[];
}
/**
 * @brief Configurations to be set when pushing media streams to CDN.
 */
export interface TranscoderParam {
    /**
     * @brief The room ID of the media stream
     */
    room_id: string;
    /**
     * @brief The user ID of the media stream
     */
    user_id: string;
    /**
     * @brief the target address of the CDN
     */
    uri: string;
    /**
     * @brief Audio transcoding configurations.
     */
    audio_param: TranscoderAudioParam;
    /**
     * @brief Video transcoding configurations.
     */
    video_param: TranscoderVideoParam;
    /**
     * @brief Stream mixing region configuration
     */
    layout_regions: TranscoderLayoutRegion[];
    /**
     * @brief Background color of the mixed stream
     */
    background_color: string;
    /**
     * @brief Additional data that you want to import
     */
    app_data: string;
}
/**
 * @brief Configurations to be set when pushing media streams to CDN.
 */
export interface PushSingleStreamParam {
    /**
     * @brief The room ID of the media stream
     */
    room_id: string;
    /**
     * @brief The user ID of the media stream
     */
    user_id: string;
    /**
     * @brief the target address of the CDN
     */
    uri: string;
    /**
     * @brief Background color of the mixed stream
     */
    is_screen_stream: boolean;
}
/**
 * @brief Audio transcoding configurations.
 */
export interface TranscoderAudioParam {
    /**
     * @brief The sample rate(kHz). Supported sample rates: 32Khz, 44.1Khz, 48Khz. Defaults to 48Khz.
     */
    i32_sample_rate: number;
    /**
     * @brief The number of channels. Supported channels: 1, 2.  Defaults to 2.
     */
    i32_channel_num: number;
    /**
     * @brief The bitrate(Kbps) in range of [32Kbps, 192Kbps]. Defaults to 64Kbps.
     */
    i32_bitrate_kbps: number;
    /**
     * @brief AAC profile.  Defaults to `0`.
     */
    audio_codec_profile: TranscoderAudioCodecProfile;
}
/**
 * @brief Video configurations in stream mixing
 */
export interface TranscoderVideoParam {
    /**
     * @brief Width in px of the mixed video stream.
     *        The value must be an even number. Odd number will be directly rejected, causing the stream mixing to fail.
     */
    i32_width: number;
    /**
     * @brief Height in px of the mixed video stream.
     *        The value must be an even number. Odd number will be directly rejected, causing the stream mixing to fail.
     */
    i32_height: number;
    /**
     * @brief The frame rate. The default value is `15`. The range is `[1, 60]`. If the value is not legal, the SDK uses the default value.
     */
    i32_fps: number;
    /**
     * @brief GOP. The default value is `4`. The range is `[1, 5]`. The unit is second. If the value is not legal, the SDK uses the default value.
     */
    i32_gop: number;
    /**
     * @brief The default value is self-adaptive. The range is `[1, 10000]`. The unit is kbps. If the value is not legal, the SDK uses the default value.
     */
    i32_bitrate_kbps: number;
    /**
     * @brief Video encoding profile.
     */
    video_codec_profile: TranscoderVideoCodecProfile;
    /**
     * @brief Whether to push streams with low latency:
     * + True: Yes
     * + False: No
     */
    lowLatency: boolean;
}
/**
 * @brief Layout information for one of the video streams to be mixed.
 *        After starting to push streams to CDN and mixing multiple video streams, you can set the layout information for each of them.
 */
export interface TranscoderLayoutRegion {
    /**
     * @brief The user ID of the user who publishes the video stream. Required.
     */
    region_id: string;
    /**
     * @brief The room ID of the media stream. Required.
     *        If the media stream is the stream forwarded by [startForwardStreamToRooms](#startforwardstreamtorooms), you must set the roomID to the room ID of the target room.
     */
    room_id: string;
    /**
     * @brief The normalized horizontal coordinate value of the top left end vertex of the user's view, ranging within [0.0, 1.0).
     *        The view's position is determined by the position of its top left end vertex in the coordinate of the canvas. The coordinate is formed  with the top side of the canvas as the x-axis, the left side as the y-axis, and the top left end vertex as the origin point.
     */
    x: number;
    /**
     * @brief The normalized vertical coordinate value of the top left end vertex of the user's view, ranging within [0.0, 1.0).
     *        The view's position is determined by the position of its top left end vertex in the coordinate of the canvas. The coordinate is formed  with the top side of the canvas as the x-axis, the left side as the y-axis, and the top left end vertex as the origin point.
     */
    y: number;
    /**
     * @brief The normalized width of the user's view, ranging within (0.0, 1.0].
     */
    width: number;
    /**
     * @brief The normalized height of the user's view, ranging within (0.0, 1.0].
     */
    height: number;
    /**
     * @brief Transparency value, the range is [0,255]
     */
    alpha: number;
    /**
     * @brief The layer on which the video is rendered. The range is [0, 100]. 0 for the bottom layer, and 100 for the top layer.
     */
    i32_z_order: number;
    /**
     * @brief Whether the source user of the stream is a local user:
     * + True: Yes
     * + False: No
     */
    local_user: boolean;
    /**
     * @brief Whether the stream comes from screen sharing:
     * + True: Yes
     * + False: No
     */
    screen_stream: boolean;
    /**
     * @brief The stream mixing content type. The default value is `kHasAudioAndVideo`.
     */
    content_control: TranscoderContentControlType;
    /**
     * @brief Video rendering scale mode
     */
    render_mode: TranscoderRenderMode;
}
/**
 * @brief Types of streams to be mixed
 */
export declare enum TranscoderContentControlType {
    /**
     * @brief Audio and video
     */
    kHasAudioAndVideo = 0,
    /**
     * @brief Audio only
     */
    kHasAudioOnly = 1,
    /**
     * @brief Video only
     */
    kHasVideoOnly = 2
}
/**
 * @brief Video encoding format
 */
export declare enum TranscoderVideoCodecProfile {
    /**
     * @brief H264 baseline profile
     */
    kByteH264ProfileBaseline = 0,
    /**
     * @brief H264 main profile
     */
    kByteH264ProfileMain = 1,
    /**
     * @brief H264 high profile
     */
    kByteH264ProfileHigh = 2,
    /**
     * @brief Custom baseline profile
     */
    kByteVC1ProfileBaseline = 3,
    /**
     * @brief Custom main profile
     */
    kByteVC1ProfileMain = 4,
    /**
     * @brief Custom high profile
     */
    kByteVC1ProfileHigh = 5
}
/**
 * @brief AAC profile. Defaults to `0`.
 */
export declare enum TranscoderAudioCodecProfile {
    /**
     * @brief Low-Complexity profile (AAC-LC)
     */
    kByteAACProfileLC = 0,
    kByteAACProfileMain = 1,
    /**
     * @brief HE-AAC profile (AAC LC with SBR)
     */
    kByteAACProfileHEv1 = 2,
    /**
     * @brief HE-AAC v2 profile (AAC LC with SBR and Parametric Stereo)
     */
    kByteAACProfileHEv2 = 3
}
/**
 * @brief Video rendering scale mode
 */
export declare enum TranscoderRenderMode {
    /**
     * @hidden
     */
    kRenderUnknown = 0,
    /**
     * @brief Fill and Crop.
     *        The video frame is scaled with fixed aspect ratio, until it completely fills the canvas. The region of the video exceeding the canvas will be cropped.
     */
    kRenderHidden = 1,
    /**
     * @brief Fit.
     *        The video frame is scaled with fixed aspect ratio, until it fits just within the canvas. Other part of the canvas is filled with the background color.
     */
    kRenderFit = 2,
    /**
     * @brief Fill the canvas.
     *        The video frame is scaled to fill the canvas. During the process, the aspect ratio may change.
     */
    kRenderAdaptive = 3
}
/**
 * @brief Media streaming network quality.
 */
export declare enum NetworkQuality {
    /**
     * @brief Network quality unknown.
     */
    kNetworkQualityUnknown = 0,
    /**
     * @brief The network quality is excellent.
     */
    kNetworkQualityExcellent = 1,
    /**
     * @brief The subjective feeling is similar to kNetworkQualityExcellent, but the bit rate may be slightly lower.
     */
    kNetworkQualityGood = 2,
    /**
     * @brief Subjective feelings are flawed but do not affect communication.
     */
    kNetworkQualityPoor = 3,
    /**
     * @brief Can barely communicate but not smoothly.
     */
    kNetworkQualityBad = 4,
    /**
     * @brief The quality of the network is very poor and communication is basically impossible.
     */
    kNetworkQualityVbad = 5
}
/**
 * @detail 85534
 * @brief Result of sending messages and the reason of failure if it fails.
 */
export declare enum MessageSendResultCode {
    /**
     * @brief The P2P message has been sent successfully.
     */
    MESSAGE_CODE_SUCCESS = 0,
    /**
     * @brief The room-wide broadcasting message has been sent successfully.
     */
    MESSAGE_CODE_ROOM_SUCCESS = 200,
    /**
     * @brief Failure. Sending timeout.
     */
    MESSAGE_CODE_ERROR_TIMEOUT = 1,
    /**
     * @brief Failure. Channel disconnected.
     */
    MESSAGE_CODE_ERROR_BROKEN = 2,
    /**
     * @brief Failure. Recipient not found.
     */
    MESSAGE_CODE_ERROR_NOT_RECEIVER = 3,
    /**
     * @brief Failure. The sender of the message did not join the room
     */
    MESSAGE_CODE_ERROR_NOT_JOIN = 100,
    /**
     * @brief Failure. No data transmission channel connection available
     */
    MESSAGE_CODE_ERROR_NO_CONNECTION = 102,
    /**
     * @brief Failure. Message exceeds the range of the permitted size, 64 KB.
     */
    MESSAGE_CODE_ERROR_EXCEED_MAX_LENGTH = 103,
    /**
     * @brief Failure. The id of the recipient is empty
     */
    MESSAGE_CODE_ERROR_EMPTY_USER = 104,
    /**
     * @brief Failure. Unknown error
     */
    MESSAGE_CODE_ERROR_UNKNOWN = 1000
}
/**
 * @brief Audio mix file playback status.
 */
export declare enum AudioMixingState {
    /**
     * @brief Mix loaded
     */
    kAudioMixingStatePreloaded = 0,
    /**
     * @brief Mix is playing
     */
    kAudioMixingStatePlaying = 1,
    /**
     * @brief Mix Pause
     */
    kAudioMixingStatePaused = 2,
    /**
     * @brief Mixing stopped
     */
    kAudioMixingStateStopped = 3,
    /**
     * @brief Mix playback failed
     */
    kAudioMixingStateFailed = 4,
    /**
     * @brief End of mixing
     */
    kAudioMixingStateFinished = 5
}
/**
 * @detail 85534
 * @brief Error code for audio mixing
 */
export declare enum AudioMixingError {
    /**
     * @brief OK
     */
    kAudioMixingErrorOk = 0,
    /**
     * @brief Preload failed. Invalid path or the length exceeds 20s.
     */
    kAudioMixingErrorPreloadFailed = 1,
    /**
     * @brief Mixing failed. Invalid path or fail to open the file.
     */
    kAudioMixingErrorStartFailed = 2,
    /**
     * @brief Invalid mixID
     */
    kAudioMixingErrorIdNotFound = 3,
    /**
     * @brief Invalid position
     */
    kAudioMixingErrorSetPositionFailed = 4,
    /**
     * @brief Invalid volume. The range is [0, 400].
     */
    kAudioMixingErrorInValidVolume = 5,
    /**
     * @brief Another file was preloaded for mixing. Call [unloadAudioMixing](#unloadaudiomixing) first.
     */
    kAudioMixingErrorLoadConflict = 6,
    /**
     * @brief Do not support the mix type.
     */
    kAudioMixingErrorIdTypeNotMatch = 7,
    /**
     * @brief Invalid pitch value.
     */
    kAudioMixingErrorInValidPitch = 8,
    /**
     * @brief Invalid audio track.
     */
    kAudioMixingErrorInValidAudioTrack = 9,
    /**
     * @brief Mixing starting
     */
    kAudioMixingErrorIsStarting = 10,
    /**
     * @brief Invalid playback speed
     */
    kAudioMixingErrorInValidPlaybackSpeed = 11
}
/**
 * @detail 85534
 * @brief Callback warning code. The warning code indicates that there is a problem within the SDK and is trying to recover. Warning codes only serve as notifications.
 */
export declare enum WarningCode {
    /**
     * @brief Failed to enter the room.
     *        When you call the first time to join the room or disconnect and reconnect due to poor network conditions, the room entry fails due to a server error. The SDK automatically retries the room.
     */
    kWarningCodeJoinRoomFailed = -2001,
    /**
     * @brief Release audio & video stream failed.
     *        When you publish audio & video streams in your room, the publication fails due to a server error. The SDK automatically retries the release.
     */
    kWarningCodePublishStreamFailed = -2002,
    /**
     * @brief Subscription to audio & video stream failed.
     *         The subscription failed because the audio & video stream for the subscription could not be found in the current room. The SDK will automatically retry the subscription. If the subscription fails, it is recommended that you exit the retry.
     */
    kWarningCodeSubscribeStreamFailed404 = -2003,
    /**
     * @brief Subscription to audio & video stream failed.
     *        When you subscribe to audio & video streams in your room, the subscription fails due to a server error. The SDK automatically retries the subscription.
     */
    kWarningCodeSubscribeStreamFailed5xx = -2004,
    /**
     * @brief This warning is triggered when you call `setUserVisibility` to set yourself unvisible to others and then try to publish the flow.
     */
    kWarningCodePublishStreamForbiden = -2009,
    /**
     * @brief Sending a custom broadcast message failed, you are not currently in the room.
     */
    kWarningCodeSendCustomMessage = -2011,
    /**
     * @brief When the number of people in the room exceeds 500, stop sending `onUserJoined` and `onUserLeave` callbacks to existing users in the room, and prompt all users in the room via broadcast.
     */
    kWarningCodeUserNotifyStop = -2013,
    /**
     * @brief user had published in other room or had published public stream.
     */
    kWarningCodeUserInPublish = -2014,
    /**
     * @brief user had published in other room or had published public stream.
     */
    kWarningCodeOldRoomBeenReplaced = -2016,
    /**
     * @brief The old room has been replaced by new room with the same roomId
     */
    kWarningCodeInEchoTestMode = -2017,
    /**
     * @brief The camera permission is abnormal, and the current application does not obtain the camera permission.
     */
    kWarningCodeNoCameraPermission = -5001,
    /**
     * @hidden
     * @brief Setting the screen audio capture type with `setScreenAudioSourceType` after calling `publishScreen` is not supported, please set before `publishScreen`.
     */
    kWarningCodeSetScreenAudioSourceTypeFailed = -5009,
    /**
     * @brief Setting the audio capture method for screen sharing via `setScreenAudioStreamIndex` after calling `publishScreen` is not supported.
     */
    kWarningCodeSetScreenAudioStreamIndexFailed = -5010,
    /**
     * @brief Invalid pitch value setting
     */
    kWarningCodeInvalidVoicePitch = -5011,
    /**
     * @brief Invalid audio format setting
     */
    kWarningCodeInvalidAudioFormat = -5012,
    /**
     * @brief Mixed use of old and new interfaces for external audio sources
     */
    kWarningCodeInvalidCallForExtAudio = -5013,
    /**
     * @brief The specified internal rendering canvas handle is invalid.
     *        This callback is triggered when you specify an invalid canvas handle when you call [setupLocalVideo(85532#setuplocalvideo) or [setupRemoteVideo](85532#setupremotevideo).
     */
    kWarningCodeInvalidCanvasHandle = -6001,
    /**
     * @brief The authentication file is invalid. When checking the status of the authentication file, if the local file is inconsistent with the remote file, a
     *        second warning will be triggered.
     */
    kWarningLicenseFileExpired = -7001
}
/**
 * @brief The cpu and memory information used by App .
 *         The information is periodically (2s) notified to the user by the SDK via `onSysStats` callback.
 */
export interface SysStats {
    /**
     * @brief Current system CPU cores
     */
    cpu_cores: number;
    /**
     * @brief The cpu usage rate of the current application, the value range is [0,1].
     */
    cpu_app_usage: number;
    /**
     * @brief The cpu usage rate of the current system, the value range is [0,1].
     */
    cpu_total_usage: number;
    /**
     * @brief The memory usage of the current application (in MB)
     */
    memory_usage: number;
    /**
     * @brief Full memory (in MB)
     */
    full_memory: number;
    /**
     * @brief System used memory (in MB)
     */
    total_memory_usage: number;
    /**
     * @brief Free allocable memory (in MB)
     */
    free_memory: number;
    /**
     * @brief Memory usage of the current application (in %)
     */
    memory_ratio: number;
    /**
     * @brief System memory usage (in %)
     */
    total_memory_ratio: number;
}
/**
 * @detail 85534
 * @brief Callback error code.
 *        When an unrecoverable error is encountered inside the SDK, the user is notified via the `onError` callback.
 */
export declare enum ErrorCode {
    /**
     * @brief Token  is invalid.
     *        The Token used when joining the room is invalid or expired. The user is required to retrieve the token and call the `updateToken` to update the token.
     */
    kErrorCodeInvalidToken = -1000,
    /**
     * @brief Join room error.
     *        An unknown error occurred while joining the room, which caused the joining room to fail. Users are required to rejoin the room.
     */
    kErrorCodeJoinRoom = -1001,
    /**
     * @brief No permission to publish audio & video streams.
     *        The user failed to publish the audio & video stream in the room. The reason for the failure is that the user does not have permission to publish the stream.
     */
    kErrorCodeNoPublishPermission = -1002,
    /**
     * @brief No subscription permissions for audio & video streams.
     *        The user failed to subscribe to the audio & video stream in the room where the user is located. The reason for the failure is that the user does not have permission to subscribe to the stream.
     */
    kErrorCodeNoSubscribePermission = -1003,
    /**
     * @brief The user has been removed from the room because the same user joined the room on the other client.
     */
    kErrorCodeDuplicateLogin = -1004,
    /**
     * @brief The user has been removed from the room by the administrator via a OpenAPI call.
     */
    kErrorCodeKickedOut = -1006,
    /**
     * @brief When calling `createRTCRoom`, if the roomid is illegal, it will return null and throw the error
     */
    kRoomErrorCodeRoomIdIllegal = -1007,
    /**
     * @brief Token expired. Call `joinRoom` to rejoin with a valid Token.
     */
    kRoomErrorTokenExpired = -1009,
    /**
     * @brief The Token you provided when calling `updateToken` is invalid.
     */
    kRoomErrorUpdateTokenWithInvalidToken = -1010,
    /**
     * @brief Users have been removed from the room because the administrator dismissed the room by calling OpenAPI.
     */
    kErrorCodeRoomDismiss = -1011,
    /**
     * @brief Join room error.
     *        The LICENSE billing account does not use the LICENSE_AUTHENTICATE SDK while entering the room, which caused the joining room to fail.
     */
    kErrorCodeJoinRoomWithoutLicenseAuthenticateSDK = -1012,
    /**
     * @brief there is a room with the same roomId，whose room id is the same with echo test
     */
    kErrorCodeRoomAlreadyExist = -1013,
    /**
     * @brief Subscription to audio & video stream failed, the total number of subscribed audio & video streams exceeded the upper limit.
     *        In the game scenario, in order to ensure the performance and quality of audio & video calls, the server will limit the total number of audio & video streams subscribed by the user. When the total number of audio & video streams subscribed by the user has reached the maximum, continuing to subscribe to more streams will fail, and the user will receive this error notification.
     */
    kErrorCodeOverStreamSubscribeLimit = -1070,
    /**
     * @brief Publishing flow failed, the total number of publishing flows exceeds the upper limit. The
     *        RTC system limits the total number of streams published in a single room, including video streams, audio streams, and screen streams. Local users will fail to publish streams to the room when the maximum number of published streams in the room has been reached, and will receive this error notification.
     */
    kErrorCodeOverStreamPublishLimit = -1080,
    /**
     * @brief Publishing the screen stream failed, and the total number of publishing streams exceeded the upper limit. The
     *        RTC system limits the total number of streams published in a single room, including video streams, audio streams, and screen streams. Local users will fail to publish streams to the room when the maximum number of published streams in the room has been reached, and will receive this error notification.
     */
    kErrorCodeOverScreenPublishLimit = -1081,
    /**
     * @brief The total number of published video streams exceeds the upper limit.
     *        The RTC system limits the number of video streams posted in a single room. If the maximum number of video streams posted in the room has been reached, local users will fail to post video streams to the room again and will receive this error notification.
     */
    kErrorCodeOverVideoPublishLimit = -1082,
    /**
     * @brief A/V synchronization failed.
     *        Current source audio ID has been set by other video publishers in the same room.
     *        One single audio source cannot be synchronized with multiple video sources at the same time.
     */
    kErrorCodeInvalidAudioSyncUidRepeated = -1083,
    /**
     * @brief The user has been removed from the room due to the abnormal status of server.
     *        SDK  is disconnected with the signaling server. It will not reconnect automatically. Please contact technical support.
     */
    kErrorCodeAbnormalServerStatus = -1084
}
/**
 * @brief SDK  Network connection type.
 */
export declare enum NetworkType {
    /**
     * @brief Network connection type unknown.
     */
    kNetworkTypeUnknown = -1,
    /**
     * @brief The network connection has been disconnected.
     */
    kNetworkTypeDisconnected = 0,
    /**
     * @brief The network connection type is LAN.
     */
    kNetworkTypeLAN = 1,
    /**
     * @brief The network connection type is Wi-Fi (including hotspots).
     */
    kNetworkTypeWIFI = 2,
    /**
     * @brief The network connection type is 2G mobile network.
     */
    kNetworkTypeMobile2G = 3,
    /**
     * @brief The network connection type is 3G mobile network.
     */
    kNetworkTypeMobile3G = 4,
    /**
     * @brief The network connection type is 4G mobile network.
     */
    kNetworkTypeMobile4G = 5,
    /**
     * @brief The network connection type is 5G mobile network.
     */
    kNetworkTypeMobile5G = 6
}
/**
 * @brief Audio & video quality feedback problem
 */
export declare enum ProblemFeedbackOption {
    /**
     * @brief Every thing is OK.
     */
    kProblemFeedbackOptionNone = 0,
    /**
     * @brief Issues not included in the list
     */
    kProblemFeedbackOptionOtherMessage = 1,
    /**
     * @brief Unclear voice
     */
    kProblemFeedbackOptionAudioNotClear = 2,
    /**
     * @brief Unclear video
     */
    kProblemFeedbackOptionVideoNotClear = 3,
    /**
     * @brief Audio & video out of sync
     */
    kProblemFeedbackOptionNotSync = 4,
    /**
     * @brief Audio stall
     */
    kProblemFeedbackOptionAudioLagging = 5,
    /**
     * @brief Video stall
     */
    kProblemFeedbackOptionVideoLagging = 6,
    /**
     * @brief Connection failed
     */
    kProblemFeedbackOptionDisconnected = 7,
    /**
     * @brief No sound
     */
    kProblemFeedbackOptionNoAudio = 8,
    /**
     * @brief No picture
     */
    kProblemFeedbackOptionNoVideo = 9,
    /**
     * @brief Too little sound
     */
    kProblemFeedbackOptionAudioStrength = 10,
    /**
     * @brief Echo noise
     */
    kProblemFeedbackOptionEcho = 11,
    /**
     * @brief High latency for the ear monitor
     */
    KFeedbackOptionEarBackDelay = 12
}
/**
 * @brief Whether to turn on release performance fallback
 */
export declare enum PerformanceAlarmMode {
    /**
     * @brief Not enabled Release performance fallback
     */
    kPerformanceAlarmModeNormal = 0,
    /**
     * @brief Open Release Performance Rollback
     */
    kPerformanceAlarmModeSimulcast = 1
}
/**
 * @brief Reasons of performance-related alarms
 */
export declare enum PerformanceAlarmReason {
    /**
     * @brief The poor network causes the transmission performance to fall back. This reason is only received when sending performance fallback is turned on.
     */
    kPerformanceAlarmReasonBandwidthFallbacked = 0,
    /**
     * @brief Network performance recovery, transmission performance rollback recovery. This reason is only received when sending performance fallback is turned on.
     */
    kPerformanceAlarmReasonBandwidthResumed = 1,
    /**
     * @brief If the send performance fallback is not turned on, when receiving this alarm, it means that the performance is insufficient;
     *        If the send performance fallback is turned on, when receiving this alarm, it means that the performance is insufficient and the send performance fallback has occurred.
     */
    kPerformanceAlarmReasonPerformanceFallbacked = 2,
    /**
     * @brief If the send performance fallback is not turned on, when receiving this alarm, it means that the performance shortage has been restored;
     *         If the send performance fallback is turned on, when receiving this alarm, it means that the performance shortage has been restored and the send performance fallback has occurred. Recovery.
     */
    kPerformanceAlarmReasonPerformanceResumed = 3
}
export declare enum MediaDeviceError {
    kMediaDeviceErrorOK = 0,
    kMediaDeviceErrorDeviceNoPermission = 1,
    kMediaDeviceErrorDeviceBusy = 2,
    kMediaDeviceErrorDeviceFailure = 3,
    kMediaDeviceErrorDeviceNotFound = 4,
    kMediaDeviceErrorDeviceDisconnected = 5
}
export declare enum JoinRoomType {
    kJoinRoomTypeFirst = 0,
    kJoinRoomTypeReconnected = 1
}
/**
 * @brief Local audio stream statistics, reference period 2s.
 *         After the local user publishes the audio stream successfully, the SDK will periodically notify the user through `onLocalStreamStats`
 *         The transmission status of the published audio stream during this reference period. This data structure is the type of parameter that is called back to the user.
 */
export interface LocalAudioStats {
    /**
     * @brief Audio packet loss rate. The audio uplink packet loss rate in this reference period is % and the value range is [0,1].
     */
    audio_loss_rate: number;
    /**
     * @brief Send rate. The audio transmission rate in the reference period is kbps.
     */
    send_kbitrate: number;
    /**
     * @brief Acquisition sampling rate. Audio sampling rate information collected in the reference period, in units of Hz.
     */
    record_sample_rate: number;
    /**
     * @brief Statistical interval. The interval of this reference period is in ms.
     *        This field is used to set the reference period for the callback. The default setting is 2s.
     */
    stats_interval: number;
    /**
     * @brief Round-trip time. The unit is ms.
     */
    rtt: number;
    /**
     * @brief Number of audio channels.
     */
    num_channels: number;
    /**
     * @brief Audio transmission sampling rate. Audio transmission sampling rate information in the reference period, in Hz.
     */
    sent_sample_rate: number;
    /**
     * @brief Audio uplink network jitter in ms.
     */
    jitter: number;
}
/**
 * @brief Local video stream statistics, reference period 2s.
 *        After a local user publishes a video stream successfully, the SDK will periodically notify the user through `onLocalStreamStats`
 *        The delivery status of the published video stream during this reference period. This data structure is the type of parameter that is called back to the user.
 */
export interface LocalVideoStats {
    /**
     * @brief TX bitrate in Kbps of the video stream with the highest resolution within the reference period
     */
    sent_kbitrate: number;
    /**
     * @brief Sampling frame rate in fps of video capture during this reference period
     */
    input_frame_rate: number;
    /**
     * @brief TX frame rate in fps of the video stream with the highest resolution within the reference period
     */
    sent_frame_rate: number;
    /**
     * @brief Encoder-output frame rate in fps of the video stream with the highest resolution within the reference period
     */
    encoder_output_frame_rate: number;
    /**
     * @brief Local-rendering frame rate in fps during this reference period
     */
    renderer_output_frame_rate: number;
    /**
     * @brief Statistical interval. The interval of this reference period is in ms.
     *        This field is used to set the reference period for the callback. The default setting is 2s.
     */
    stats_interval: number;
    /**
     * @brief Video packet loss rate. The video uplink packet loss rate in this reference period ranges from  [0,1].
     */
    video_loss_rate: number;
    /**
     * @brief Round-trip time in ms.
     */
    rtt: number;
    /**
     * @brief Video encoding bitrate in Kbps of the video stream with the highest resolution within the reference period.
     */
    encoded_bitrate: number;
    /**
     * @brief Video encoding width in px of the video stream with the highest resolution within the reference period
     */
    encoded_frame_width: number;
    /**
     * @brief Video encoding height in px of the video stream with the highest resolution within the reference period
     */
    encoded_frame_height: number;
    /**
     * @brief The total number of the video stream with the highest resolution within the reference period sent in the reference period.
     */
    encoded_frame_count: number;
    /**
     * @brief For the encoding type of the video
     */
    codec_type: VideoCodecType;
    /**
     * @brief Whether the media stream belongs to the user is a screen stream. You can know whether the current statistics come from mainstream or screen stream.
     */
    is_screen: boolean;
    /**
     * @brief Video uplink network jitter in ms.
     */
    jitter: number;
}
/**
 * @brief Local audio/video stream statistics and network status, the reference period is 2s.
 *        After the local user publishes the audio/video stream successfully, the SDK will periodically notify the local user through `onLocalStreamStats`
 *        The transmission status of the published audio/video stream during this reference period. This data structure is the type of parameter that is called back to the user.
 */
export interface LocalStreamStats {
    /**
     * @brief For statistics on audio streams sent by local devices.
     */
    audio_stats: LocalAudioStats;
    /**
     * @brief For statistics on video streams sent by local devices.
     */
    video_stats: LocalVideoStats;
    /**
     * @hidden
     * @brief For the media stream uplink network quality of the user you belong to.
     * @deprecated since 336.1, use onNetworkQuality(85533#onnetworkquality) instead
     */
    local_tx_quality: NetworkQuality;
    /**
     * @hidden
     * @brief The downlink network quality of the media stream belongs to the user.
     * @deprecated since 336.1, use onNetworkQuality(85533#onnetworkquality) instead
     */
    local_rx_quality: NetworkQuality;
    /**
     * @brief Whether the media stream belongs to the user is a screen stream. You can know whether the current statistics come from mainstream or screen stream.
     */
    is_screen: boolean;
}
/**
 * @brief Remote audio stream statistics, reference period 2s.
 *         After a local user subscribes to a remote audio stream successfully, the SDK periodically notifies the local user of the reception status of the subscribed audio stream during this reference period through `onRemoteStreamStats`. This data structure is the type of parameter that is called back to the local user.
 */
export interface RemoteAudioStats {
    /**
     * @brief Audio packet loss rate. The audio downlink packet loss rate in the reference period, the value range is  [0,1].
     */
    audio_loss_rate: number;
    /**
     * @brief Receiving bit rate. The audio reception rate in the reference period in kbps.
     */
    received_kbitrate: number;
    /**
     * @brief Number of audio stalls. Number of stalls in the reference period.
     */
    stall_count: number;
    /**
     * @brief Audio stall Duration. Stall duration in the reference period in ms.
     */
    stall_duration: number;
    /**
     * @brief End-to-end latency at the user experience level. The delay from the start of encoding at the sending end to the start of decoding at the receiving end, in units of ms.
     */
    e2e_delay: number;
    /**
     * @brief Play sample rate. Audio playback sample rate information within the reference period in Hz.
     */
    playout_sample_rate: number;
    /**
     * @brief Statistical interval. The interval of this reference period is in ms.
     */
    stats_interval: number;
    /**
     * @brief Round-trip time for client side to server level data transfer in ms.
     */
    rtt: number;
    /**
     * @brief The sender-server level-the receiver-link data transmission round-trip time. The unit is ms.
     */
    total_rtt: number;
    /**
     * @brief The quality of the audio stream sent by the remote user.
     * + `0`: Network quality unknown.
     * + `1`: The network quality is excellent.
     * + `2`: The subjective feeling is similar to kNetworkQualityExcellent, but the bit rate may be slightly lower.
     * + `3`: Subjective feelings are flawed but do not affect communication.
     * + `4`: Can barely communicate but not smoothly.
     * + `5`: The quality of the network is very poor and communication is basically impossible.
     */
    quality: number;
    /**
     * @brief The delay caused by the introduction of the jitter buffer mechanism. The unit is ms.
     */
    jitter_buffer_delay: number;
    /**
     * @brief Number of audio channels.
     */
    num_channels: number;
    /**
     * @brief Audio reception sampling rate. Remote audio sampling rate information received within the reference period, in Hz.
     */
    received_sample_rate: number;
    /**
     * @brief The accumulated length of the audio card occurs after the remote user joins the room as a percentage of the total effective length of the audio. The effective duration of audio refers to the duration of audio other than stopping sending audio streams and disabling audio modules after remote users enter the room to publish audio streams.
     */
    frozen_rate: number;
    /**
     * @brief Audio packet loss compensation (PLC)  total number of sample points.
     */
    concealed_samples: number;
    /**
     * @brief Audio packet loss compensation (PLC)  cumulative times.
     */
    concealment_event: number;
    /**
     * @brief Audio decoding sample rate. Audio decoding sample rate information in the reference period in Hz.
     */
    dec_sample_rate: number;
    /**
     * @brief Decoding duration. The total time-consuming decoding of the remote audio stream received within this reference period, in seconds.
     */
    dec_duration: number;
    /**
     * @brief Audio downlink network jitter in ms.
     */
    jitter: number;
}
/**
 * @brief Remote video stream statistics, reference period 2s.
 *         After the local user subscribes to the remote video stream successfully, the SDK will periodically notify the local user of the reception status of the remote video stream subscribed to during this reference period through `onRemoteStreamStats`
 *        . This data structure is the type of parameter that is called back to the local user.
 */
export interface RemoteVideoStats {
    /**
     * @brief Video Width
     */
    width: number;
    /**
     * @brief Video height
     */
    height: number;
    /**
     * @brief Video packet loss rate. Video downlink packet loss rate in the reference period, in units of %, and in the range of [0,1].
     */
    video_loss_rate: number;
    /**
     * @brief Receiving bit rate. Video reception rate within the reference period, in kbps.
     */
    received_kbitrate: number;
    /**
     * @brief The decoder outputs the frame rate. Video decoder output frame rate within the reference period, in fps.
     */
    decoder_output_frame_rate: number;
    /**
     * @brief Render frame rate. The video rendering frame rate in the reference period, in fps.
     */
    renderer_output_frame_rate: number;
    /**
     * @brief Number of stalls. Number of stalls in the reference period.
     */
    stall_count: number;
    /**
     * @brief Stall duration. The total duration of the video stall in the reference period. Unit ms.
     */
    stall_duration: number;
    /**
     * @brief End-to-end latency at the user experience level. The delay from the start of encoding at the sending end to the start of decoding at the receiving end, in units of ms.
     */
    e2eDelay: number;
    /**
     * @brief Whether the media stream belongs to the user is a screen stream. You can know whether the current data comes from mainstream or screen stream.
     */
    is_screen: number;
    /**
     * @brief Statistical interval, the interval of this reference period, in ms.
     *        This field is used to set the reference period for the callback, currently set to 2s.
     */
    stats_interval: number;
    /**
     * @brief Round-trip time in ms.
     */
    rtt: number;
    /**
     * @brief The cumulative duration of the video card of the remote user accounts for the percentage (%) of the total effective duration of the video after entering the room. The effective duration of the video refers to the duration of the video other than stopping sending the video stream and disabling the video module after the remote user enters the room to publish the video stream.
     */
    frozen_rate: number;
    /**
     * @brief For the encoding type of the video
     */
    codec_type: VideoCodecType;
    /**
     * @brief For subscripts of streams with multiple resolutions.
     */
    video_index: number;
    /**
     * @brief Video downlink network jitter in ms.
     */
    jitter: number;
}
/**
 * @brief The remote audio/video stream statistics and network status subscribed by the user, with a reference period of 2s.
 *         After the remote user subscribed to successfully publish the audio/video stream, the SDK will periodically notify local users through `onRemoteStreamStats`
 *         The reception status of the remote audio/video stream subscribed during this reference period. This data structure is the type of parameter that is called back to the local user.
 */
export interface RemoteStreamStats {
    /**
     * @brief User ID
     */
    uid: string;
    /**
     * @brief User ID. The remote user ID of the audio source.
     */
    audio_stats: RemoteAudioStats;
    /**
     * @brief For statistics on remote audio streams.
     */
    video_stats: RemoteVideoStats;
    /**
     * @hidden
     * @brief For the media stream uplink network quality of the user you belong to.
     * @deprecated since 336.1, use onNetworkQuality(85533#onnetworkquality) instead
     */
    remote_tx_quality: NetworkQuality;
    /**
     * @hidden
     * @brief The downlink network quality of the media stream belongs to the user.
     * @deprecated since 336.1, use onNetworkQuality(85533#onnetworkquality) instead
     */
    remote_rx_quality: NetworkQuality;
    /**
     * @brief Whether the media stream belongs to the user is a screen stream. You can know whether the current statistics come from mainstream or screen stream.
     */
    is_screen: boolean;
}
export declare enum MuteState {
    kMuteStateOff = 0,
    kMuteStateOn = 1
}
/**
 * @brief Stream type.
 */
export declare enum StreamIndex {
    /**
     * @brief Main stream which includes video captured by cameras or audio captured by microphone
     */
    kStreamIndexMain = 0,
    /**
     * @brief Screen stream to be shared
     * Screen recording stream or sounds coming from the sound card
     */
    kStreamIndexScreen = 1
}
/**
 * @brief Events during pushing streams to CDN
 */
export declare enum StreamMixingEvent {
    /**
     * @brief Request to start pushing streams to CDN
     */
    kStreamMixingStart = 1,
    /**
     * @brief ask to push streams to CDN started
     */
    kStreamMixingStartSuccess = 2,
    /**
     * @brief Failed to start the task to push streams to CDN
     */
    kStreamMixingStartFailed = 3,
    /**
     * @brief Request to update the configuration for the task to push streams to CDN
     */
    kStreamMixingUpdate = 4,
    /**
     * @brief Successfully update the configuration for the task to push streams to CDN
     */
    kStreamMixingUpdateSuccess = 5,
    /**
     * @brief Failed to update the configuration for the task to push streams to CDN
     */
    kStreamMixingUpdateFailed = 6,
    /**
     * @brief Request to stop the task to push streams to CDN
     */
    kStreamMixingStop = 7,
    /**
     * @brief The task to push streams to CDN stopped
     */
    kStreamMixingStopSuccess = 8,
    /**
     * @brief Failed to stop the task to push streams to CDN
     */
    kStreamMixingStopFailed = 9,
    /**
     * @brief Timeout for the request to update the configuration for the task to push streams to CDN.
     */
    kStreamMixingChangeMixType = 10,
    /**
     * @brief Got the first frame of the mixed audio stream by client.
     */
    kStreamMixingFirstAudioFrameByClientMix = 11,
    /**
     * @brief Got the first frame of the mixed video stream by client.
     */
    kStreamMixingFirstVideoFrameByClientMix = 12,
    /**
     * @brief Timeout for the request to update the configuration for the task to push streams to CDN
     */
    kStreamMixingUpdateTimeout = 13,
    /**
     * @brief Timeout for the request to start the task to push streams to CDN
     */
    kStreamMixingStartTimeout = 14,
    /**
     * @brief Error in the parameters of the request for the task to push streams to CDN
     */
    kStreamMixingRequestParamError = 15,
    /**
     * @brief Mixing image.
     */
    kStreamMixingMixImageEvent = 16
}
/**
 * @brief Events during pushing streams to CDN
 */
export declare enum SingleStreamPushEvent {
    /**
     * @brief Starting pushing a single stream to CDN.
     */
    kSingleStreamPushStart = 1,
    /**
     * @brief Successfully pushed a single stream to CDN.
     */
    kSingleStreamPushSuccess = 2,
    /**
     * @brief Failed to push a single stream to CDN.
     */
    kSingleStreamPushFailed = 3,
    /**
     * @brief Stop pushing a single stream to CDN.
     */
    kSingleStreamPushStop = 4,
    /**
     * @brief Request timed out. Please check network status and retry.
     */
    kSingleStreamPushTimeout = 5,
    /**
     * @brief Request failed due to invalid parameter.
     */
    kSingleStreamPushParamError = 6
}
/**
 * @brief Stream mixing type
 */
export declare enum StreamMixingType {
    /**
     * @brief Server-side stream mixing
     */
    kStreamMixingTypeByServer = 0,
    /**
     * @brief Intelligent stream mixing. The SDK will intelligently decide that a stream mixing task would be done on the client or the server.
     */
    kStreamMixingTypeByClient = 1
}
/**
 * @brief Information about the remote stream
 */
export interface RemoteStreamKey {
    /**
     * @brief The room ID of the media stream.
     *        If the media stream is the stream forwarded by `startForwardStreamToRooms`, you must set the roomID to the room ID of the target room.
     */
    room_id: string;
    /**
     * @brief The ID of the user who published the stream.
     */
    user_id: string;
    /**
     * @brief Stream type.
     */
    stream_index: StreamIndex;
}
/**
 * @brief Local recording parameter configuration
 */
export interface RecordingConfig {
    /**
     * @brief The absolute path to save the recording file. You need to specify a legal path with read and write permissions.
     */
    dir_path: string;
    /**
     * @brief Recording stored file format.
     * + aac : 0
     * + mp4 : 1
     */
    file_type: number;
}
export declare enum RecordingType {
    /**
     * @brief 只录制音频
     */
    kRecordAudioOnly = 0,
    /**
     * @brief 只录制视频
     */
    kRecordVideoOnly = 1,
    /**
     * @brief 同时录制音频和视频
     */
    kRecordVideoAndAudio = 2
}
/**
 * @brief Verification information required to use automatic speech recognition services
 */
export interface RTCASRConfig {
    /**
     * @brief Application ID
     */
    app_id: string;
    /**
     * @brief User ID
     */
    user_id: string;
    /**
     * @brief For authentication methods.
     * + `0`: Via Token
     * + `1`: Via Signature
     */
    authorization_type: number;
    /**
     * @brief Access token
     */
    access_token: string;
    /**
     * @brief Private key. Signature  cannot be empty in authentication mode, and it is empty in token authentication mode.
     */
    secret_key: string;
    /**
     * @brief For scenario information.
     */
    cluster: string;
}
export declare enum StreamRemoveReason {
    kStreamRemoveReasonUnpublish = 0,
    kStreamRemoveReasonPublishFailed = 1,
    kStreamRemoveReasonKeepLiveFailed = 2,
    kStreamRemoveReasonClientDisconnected = 3,
    kStreamRemoveReasonRepublish = 4,
    kStreamRemoveReasonOther = 5
}
/**
 * @brief Reason of the Fallback or reverting from a Fallback of the subscribed stream or the publishing stream
 */
export declare enum FallbackOrRecoverReason {
    /**
     * @brief The default: Fallback due to an unknown reason that is neither infufficienclt bandwidth of the network nor poor-performance of the device
     */
    kFallbackOrRecoverReasonUnknown = -1,
    /**
     * @brief Fallback of the subscribed stream due to insufficient bandwidth of the network
     */
    kFallbackOrRecoverReasonSubscribeFallbackByBandwidth = 0,
    /**
     * @brief Fallback of the subscribed stream for poor-performance of the device
     */
    kFallbackOrRecoverReasonSubscribeFallbackByPerformance = 1,
    /**
     * @brief Reverting from a Fallback of the subscribed stream due to the recovery of the network bandwidth
     */
    kFallbackOrRecoverReasonSubscribeRecoverByBandwidth = 2,
    /**
     * @brief Reverting from a Fallback of the subscribed stream due to the amelioration of the device performance
     */
    kFallbackOrRecoverReasonSubscribeRecoverByPerformance = 3,
    /**
     * @brief Fallback of the publishing stream due to Insufficient bandwidth of the network
     */
    kFallbackOrRecoverReasonPublishFallbackByBandwidth = 4,
    /**
     * @brief Fallback of the publishing stream due to poor-performance of the device
     */
    kFallbackOrRecoverReasonPublishFallbackByPerformance = 5,
    /**
     * @brief Reverting from a Fallback of the publishing stream due to the recovery of the network bandwidth
     */
    kFallbackOrRecoverReasonPublishRecoverByBandwidth = 6,
    /**
     * @brief Reverting from a Fallback of the publishing stream due to the amelioration of the device performance
     */
    kFallbackOrRecoverReasonPublishRecoverByPerformance = 7
}
/**
 * @brief Information of stream switching due to a Fallback
 */
export interface RemoteStreamSwitch {
    /**
     * @brief User ID of the publisher of the subscribed media stream
     */
    uid: string;
    /**
     * @brief Whether it is a screen-sharing stream
     */
    is_screen: boolean;
    /**
     * @brief The quality index of the subscribed stream before the stream switching
     */
    before_video_index: number;
    /**
     * @brief The quality index of the subscribed stream after the stream switching
     */
    after_video_index: number;
    /**
     * @brief Whether a video stream before the stream switching
     */
    before_enable: boolean;
    /**
     * @brief Whether a video stream after the stream switching
     */
    after_enable: boolean;
    /**
     * @brief Reason of the Fallback or reverting from the Fallback of the subscribed stream.
     */
    reason: FallbackOrRecoverReason;
}
/**
 * @brief Information on video frame rotation angle
 */
export declare enum VideoRotation {
    /**
     * @brief Video does not rotate
     */
    kVideoRotation0 = 0,
    /**
     * @brief Video rotates 90 degrees clockwise
     */
    kVideoRotation90 = 90,
    /**
     * @brief Video rotates 180 degrees clockwise
     */
    kVideoRotation180 = 180,
    /**
     * @brief Video rotates 270 degrees clockwise
     */
    kVideoRotation270 = 270
}
/**
 * @brief Video frame information
 */
export interface VideoFrameInfo {
    /**
     * @brief Width (pixels)
     */
    width: number;
    /**
     * @brief High (pixels)
     */
    height: number;
    /**
     * @brief Video frame clockwise rotation angle.
     */
    rotation: VideoRotation;
}
/**
 * @brief Audio properties
 */
export interface AudioPropertiesInfo {
    /**
     * @brief linear volume. The value is in linear relation to the original volume. The higher the value, the higher the volume. The range is [0,255].
     *        - [0, 25]: Silence
     *        - [26, 75]: Low volume
     *        - [76, 204]: Medium volume
     *        - [205, 255]: High volume
     */
    linear_volume: number;
    /**
     * @brief non-linear volume in dB. The value is in proportion to the log value of the original volume. You can use the value to recognize the Active Speaker in the room. The range is [-127, 0].
     *        - [-127, -60]: Silence
     *        - [-59, -40]: Low volume
     *        - [-39, -20]: Medium volume
     *        - [-19, 0]: High volume
     */
    nonlinear_volume: number;
    /**
     * @brief Voice Activity Detection (VAD) result
     *        + 1: Voice activity detected.
     *        + 0: No voice activity detected.
     *        + -1: VAD not activated.
     */
    vad: number;
    spectrum: number[];
}
/**
 * @brief Local audio properties
 */
export interface LocalAudioPropertiesInfo {
    /**
     * @brief Stream Index
     */
    stream_index: StreamIndex;
    /**
     * @brief Audio properties information
     */
    audio_properties_info: AudioPropertiesInfo;
}
/**
 * @brief Remote audio properties
 */
export interface RemoteAudioPropertiesInfo {
    /**
     * @brief Stream Index
     */
    stream_key: RemoteStreamKey;
    /**
     * @brief Audio properties information
     */
    audio_properties_info: AudioPropertiesInfo;
}
/**
 * @brief Virtual background Object
 */
export interface VirtualBackgroundSource {
    /**
     * @brief Virtual background type.
     */
    source_type: VirtualBackgroundSourceType;
    /**
     * @brief The absolute path of the specified image.
     * + You can upload a .JPG, .PNG, or .JPEG file.
     * + The image with a resolution higher than 1080p(Full HD) will be rescaled proportionally to fit in the video.
     * + If the image's aspect ratio matches the video's, the image will be rescaled proportionally to fit in the video.
     * + If the image’s aspect ratio doesn't match the video's, the shortest side (either height or width) of the image will be stretched proportionally to match the video. Then the image will be cropped to fill in the video.
     * + The transparent area in the image will be filled with white color.
     */
    source_path: string;
    source_color: number;
}
export declare enum VirtualBackgroundSourceType {
    kVirtualBackgroundSourceColor = 0,
    kVirtualBackgroundSourceImage = 1
}
/**
 * @brief Local audio stream status.
 *        SDK callbacks local audio stream status via `onLocalAudioStateChanged`
 */
export declare enum LocalAudioStreamState {
    /**
     * @brief The default initial state of the local audio.
     *         Callback to this state when the microphone stops working, corresponding to the error code kLocalAudioStreamErrorOk
     */
    kLocalAudioStreamStateStopped = 0,
    /**
     * @brief The local audio recording device started successfully.
     *         Callback to the state when the first frame of audio is collected, corresponding to the error code kLocalAudioStreamErrorOk
     */
    kLocalAudioStreamStateRecording = 1,
    /**
     * @brief The first frame of the local audio was successfully encoded.
     *         Callback to the state when the audio first frame encoding is successful, corresponding to the error code kLocalAudioStreamErrorOk
     */
    kLocalAudioStreamStateEncoding = 2,
    /**
     * @brief The local audio startup failed, and the status is called back at the following times:
     *        + The local recording device failed to start, corresponding to the error code kLocalAudioStreamErrorRecordFailure
     *        + No recording device permission was detected, corresponding to the error code kLocalAudioStreamErrorDeviceNoPermission
     *        + The audio encoding failed, corresponding to the error code kLocalAudioStreamErrorEncodeFailure
     */
    kLocalAudioStreamStateFailed = 3
}
/**
 * @detail 85534
 * @brief Error code when the local audio state changes
 *        SDK informs you via [onLocalAudioStateChanged](85533#onlocalaudiostatechanged).
 */
export declare enum LocalAudioStreamError {
    /**
     * @brief Local audio status is normal
     */
    kLocalAudioStreamErrorOk = 0,
    /**
     * @brief Local audio error cause unknown
     */
    kLocalAudioStreamErrorFailure = 1,
    /**
     * @brief No permission to start local audio recording device
     */
    kLocalAudioStreamErrorDeviceNoPermission = 2,
    /**
     * @hidden
     * @brief The local audio recording device is already in use
     * The error code is not yet in use
     */
    kLocalAudioStreamErrorDeviceBusy = 3,
    /**
     * @brief Local audio recording failed, it is recommended that you check whether the recording device is working properly
     */
    kLocalAudioStreamErrorRecordFailure = 4,
    /**
     * @brief Local audio encoding failed
     */
    kLocalAudioStreamErrorEncodeFailure = 5,
    /**
     * @brief No audio recording equipment available
     */
    kLocalAudioStreamErrorNoRecordingDevice = 6
}
/**
 * @brief Remote audio stream state.
 *         Users can learn about this status through `onRemoteAudioStateChanged`.
 */
export declare enum RemoteAudioState {
    /**
     * @brief The remote audio stream is not received.
     *        The callback [onRemoteAudioStateChanged](85533#onremoteaudiostatechanged) triggers:
     *        + Local users stop receiving remote audio streams due to kRemoteAudioStateChangeReasonLocalMuted
     *        + The remote user stops sending audio streams due to kRemoteAudioStateChangeReasonRemoteMuted
     *        + The remote user left the room, the corresponding reason is: kRemoteAudioStateChangeReasonRemoteOffline
     */
    kRemoteAudioStateStopped = 0,
    /**
     * @brief Start receiving the remote audio stream header.
     *        Just received the remote audio stream header will trigger a callback [onRemoteAudioStateChanged](85533#onremoteaudiostatechanged),
     *         The corresponding reason is: RemoteAudioStateChangeReason in "kRemoteAudioStateChangeReasonLocalUnmuted"
     */
    kRemoteAudioStateStarting = 1,
    /**
     * @brief The remote audio stream is decoding and playing normally.
     *          A callback is triggered in the following cases: [onRemoteAudioStateChanged](85533#onremoteaudiostatechanged):
     *        + The remote audio first frame was successfully decoded, and the corresponding reason is: 'kRemoteAudioStateChangeReasonLocalUnmuted' in RemoteAudioStateChangeReason
     *        + The network returned to normal from blocking, and the corresponding reason is: "kRemoteAudioStateChangeReasonNetworkRecovery ' in RemoteAudioStateChangeReason
     *        + Local users resume receiving remote audio streams, and the corresponding reason is 'kRemoteAudioStateChangeReasonLocalUnmuted ' RemoteAudioStateChangeReason
     *        + Remote users resume sending audio streams, and the corresponding reason is 'kRemoteAudioStateChangeReasonRemoteUnmuted' in RemoteAudioStateChangeReason
     */
    kRemoteAudioStateDecoding = 2,
    /**
     * @brief Remote audio streaming card.
     *         A callback is triggered when the network is blocked and the packet loss rate is greater than 40%. `onRemoteAudioStateChanged`,
     *         The corresponding reason is: "kRemoteAudioStateChangeReasonNetworkCongestion" in RemoteAudioStateChangeReasonNetworkCongestion}
     */
    kRemoteAudioStateFrozen = 3,
    /**
     * @hidden
     * @brief The remote audio stream failed to play
     * @notes  The error code is not yet used
     */
    kRemoteAudioStateFailed = 4
}
/**
 * @brief Receives the cause of the remote audio stream state change.
 *        Users can learn about this reason through `onRemoteAudioStateChanged`.
 */
export declare enum RemoteAudioStateChangeReason {
    /**
     * @brief Internal reasons
     */
    kRemoteAudioStateChangeReasonInternal = 0,
    /**
     * @brief Network blocking
     */
    kRemoteAudioStateChangeReasonNetworkCongestion = 1,
    /**
     * @brief Network back to normal
     */
    kRemoteAudioStateChangeReasonNetworkRecovery = 2,
    /**
     * @brief Local user stops receiving remote audio stream
     */
    kRemoteAudioStateChangeReasonLocalMuted = 3,
    /**
     * @brief Local users resume receiving remote audio streams
     */
    kRemoteAudioStateChangeReasonLocalUnmuted = 4,
    /**
     * @brief Remote user stops sending audio stream
     */
    kRemoteAudioStateChangeReasonRemoteMuted = 5,
    /**
     * @brief Remote user resumes sending audio stream
     */
    kRemoteAudioStateChangeReasonRemoteUnmuted = 6,
    /**
     * @brief Remote user leaves room
     */
    kRemoteAudioStateChangeReasonRemoteOffline = 7
}
/**
 * @brief Local video stream status
 */
export declare enum LocalVideoStreamState {
    /**
     * @brief Local video capture stop state
     */
    kLocalVideoStreamStateStopped = 0,
    /**
     * @brief Local video capture device activated
     */
    kLocalVideoStreamStateRecording = 1,
    /**
     * @brief After local video capture, the first frame is encoded successfully
     */
    kLocalVideoStreamStateEncoding = 2,
    /**
     * @brief Local video capture device failed to start
     */
    kLocalVideoStreamStateFailed = 3
}
/**
 * @detail 85534
 * @brief Error Codes for the local video state changed
 */
export declare enum LocalVideoStreamError {
    /**
     * @brief Normal
     */
    kLocalVideoStreamErrorOk = 0,
    /**
     * @brief Local video stream publishing failed
     */
    kLocalVideoStreamErrorFailure = 1,
    /**
     * @brief No access to the local video capture device
     */
    kLocalVideoStreamErrorDeviceNoPermission = 2,
    /**
     * @brief Local video capture equipment is occupied
     */
    kLocalVideoStreamErrorDeviceBusy = 3,
    /**
     * @brief Local video capture device does not exist
     */
    kLocalVideoStreamErrorDeviceNotFound = 4,
    /**
     * @brief Local video capture failed, it is recommended to check whether the acquisition device is working properly
     */
    kLocalVideoStreamErrorCaptureFailure = 5,
    /**
     * @brief Local video encoding failed
     */
    kLocalVideoStreamErrorEncodeFailure = 6,
    /**
     * @brief The local video capture device is disconnected. It is occupied by other programs during the call.
     */
    kLocalVideoStreamErrorDeviceDisconnected = 7
}
/**
 * @brief Remote video stream status. You will receive [onRemoteVideoStateChanged](85533#onremotevideostatechanged) callback when the state changes.
 */
export declare enum RemoteVideoState {
    /**
     * @brief The remote video stream defaults to the initial state, and the video has not yet started playing.
     */
    kRemoteVideoStateStopped = 0,
    /**
     * @brief Local user has received remote video stream header packet.
     */
    kRemoteVideoStateStarting = 1,
    /**
     * @brief The remote video stream is decoding and playing normally.
     */
    kRemoteVideoStateDecoding = 2,
    /**
     * @brief Remote video streaming card, there may be network and other reasons.
     */
    kRemoteVideoStateFrozen = 3,
    /**
     * @brief The remote video stream failed to play.
     */
    kRemoteVideoStateFailed = 4
}
/**
 * @brief Cause of remote video stream state change
 */
export declare enum RemoteVideoStateChangeReason {
    /**
     * @brief Internal reasons
     */
    kRemoteVideoStateChangeReasonInternal = 0,
    /**
     * @brief Network blocking
     */
    kRemoteVideoStateChangeReasonNetworkCongestion = 1,
    /**
     * @brief Network back to normal
     */
    kRemoteVideoStateChangeReasonNetworkRecovery = 2,
    /**
     * @brief Local user stops receiving remote video stream or local user disables video module
     */
    kRemoteVideoStateChangeReasonLocalMuted = 3,
    /**
     * @brief Local user resumes receiving remote video streams or local user enables video modules
     */
    kRemoteVideoStateChangeReasonLocalUnmuted = 4,
    /**
     * @brief The remote user stops sending the video stream or the remote user disables the video module
     */
    kRemoteVideoStateChangeReasonRemoteMuted = 5,
    /**
     * @brief Remote user resumes sending video stream or remote user enables video module
     */
    kRemoteVideoStateChangeReasonRemoteUnmuted = 6,
    /**
     * @brief The remote user leaves the channel. State transition see `onUserUnPublishStream`.
     */
    kRemoteVideoStateChangeReasonRemoteOffline = 7
}
/**
 * @brief Details of local recording
 */
export interface RecordingInfo {
    /**
     * @brief The absolute path of the recorded file, including the file name and file suffix
     */
    file_path: string;
    /**
     * @brief For the video encoding type of the recorded file.
     */
    video_codec_type: VideoCodecType;
    /**
     * @brief The width of the recorded video, in pixels. Please ignore this field for audio-only recording
     */
    width: number;
    /**
     * @brief The height of the recorded video, the unit: pixels. Please ignore this field for audio-only recording
     */
    height: number;
}
/**
 * @brief Local recording progress
 */
export interface RecordingProgress {
    /**
     * @brief The cumulative recording time of the current file, in milliseconds
     */
    duration: number;
    /**
     * @brief The size of the currently recorded file in bytes
     */
    file_size: number;
}
/**
 * @brief User information
 */
export interface RtcUser {
    /**
     * @brief User ID
     */
    user_id: string;
    /**
     * @brief Meta data
     */
    meta_data: string;
}
/**
 * @brief First frame sending state
 */
export declare enum FirstFrameSendState {
    /**
     * @brief Sending.
     */
    kFirstFrameSendStateSending = 0,
    /**
     * @brief Sent.
     */
    kFirstFrameSendStateSent = 1,
    /**
     * @brief Failed.
     */
    kFirstFrameSendStateEnd = 2
}
/**
 * @brief First frame playback state
 */
export declare enum FirstFramePlayState {
    /**
     * @brief Playing
     */
    kFirstFramePlayStatePlaying = 0,
    /**
     * @brief Play started.
     */
    kFirstFramePlayStatePlayed = 1,
    /**
     * @brief Failed.
     */
    kFirstFramePlayStateEnd = 2
}
export interface ScreenParameters {
    frame_rate: number;
    kbitrate: number;
}
/**
 * @brief Mixing type
 */
export declare enum AudioMixingType {
    /**
     * @brief Play at the local device only
     */
    kAudioMixingTypePlayout = 0,
    /**
     * @brief Send to the remote devices only
     */
    kAudioMixingTypePublish = 1,
    /**
     * @brief Play and send to remote
     */
    kAudioMixingTypePlayoutAndPublish = 2
}
/**
 * @brief Stream fallback options of publisher
 */
export declare enum PublishFallbackOption {
    /**
     * @brief Default setting. No fallback is allowed under limited network conditions.
     */
    kPublishFallbackOptionDisabled = 0,
    /**
     * @brief Under limited network conditions, the video streams that you published will degrade sequentially from the highest-quality stream to the lowest-quality stream until it can match current network conditions. See [Stream Fallback](https://docs.byteplus.com/byteplus-rtc/docs/70137) for details.
     */
    kPublishFallbackOptionSimulcast = 1
}
/**
 * @brief  Room profile
 *        Choose an appropriate room-profile option to meet the requirement of the scenario for media encoding algorithm, video profiles, and network configurations.
 *        Call `setAudioProfile` to apply another audio quality option.
 */
export declare enum RoomProfileType {
    /**
     * @brief General mode by default
     */
    kRoomProfileTypeCommunication = 0,
    kRoomProfileTypeLiveBroadcasting = 1,
    /**
     * @brief Game voice mode. Low consumption of computing resources and network data
     *        Additional performance optimizations have been made for low-end devices:
     *             + Encodes frame length 40/60 for some low-end models.
     *             + Disables software 3A audio processing for some low-end models.
     *        Enhance iOS Compatibility with other screen recordings to avoid audio recordings being interrupted by RTC.
     */
    kRoomProfileTypeGame = 2,
    /**
     * @brief Cloud game mode.
     *        Use this mode for game App requiring low latency.
     *        During poor network connection, communication experiences get worse with this mode.
     */
    kRoomProfileTypeCloudGame = 3,
    /**
     * @brief Cloud render mode featuring extra-low latency.
     *        Choose this mode if it is not a game App yet requires low latency.
     *        In this mode, latency will significantly decrease at the cost of lower audio quality as well as the bad performance with weak network signal.
     */
    kRoomProfileTypeLowLatency = 4,
    /**
     * @brief For 1 vs 1 video and audio calls
     */
    kRoomProfileTypeChat = 5,
    /**
     * @brief For video and audio chat rooms of 3 or more people
     */
    kRoomProfileTypeChatRoom = 6,
    /**
     * @brief For scenarios such as "Watch together." and "Listen together." Multiple clients are capable of playing the same videos and audios synchronically.
     *        In these scenarios, RTC does not involve the transportation of the sharing media but only synchronizes video/music playback across multiple clients via signaling.
     */
    kRoomProfileTypeLwTogether = 7,
    /**
     * @brief For the game apps demanding high-resolution audio. In this mode, RTC plays audio using the media mode only.
     */
    kRoomProfileTypeGameHD = 8,
    /**
     * @brief For the events of co-hosting in the live-streaming
     *        During a livestreaming using a CDN network, the host can invite another host to join the co-hosting event using RTC.
     */
    kRoomProfileTypeCoHost = 9,
    /**
     * @brief For interactive podcasts that the host can have video and audio interactions with the audience. The voice mode is set to communication mode to avoid volume spiking and dipping acutely.
     */
    kRoomProfileTypeInteractivePodcast = 10,
    /**
     * @brief For the online karaoke with high-quality audio and low latency
     *        In these scenarios, RTC transports the accompaniment and mixed audio, such as solo and non-realtime chorus.
     */
    kRoomProfileTypeKTV = 11,
    /**
     * @brief For the online-chorusing scenarios requiring high-quality audio and low latency. Contact our technical specialists before you apply it to your App.
     */
    kRoomProfileTypeChorus = 12,
    /**
     * @hidden
     * @brief For VR chat with support for 192 KHz audio sample rate and feature of 360 Reality AudioAudio
     */
    kRoomProfileTypeVRChat = 13,
    /**
     * @brief For scenarios of streaming live videos to only one client on the LAN. It can be applied to devices on the Internet or LAN.
     */
    kRoomProfileTypeGameStreaming = 14,
    /**
     * @brief For scenarios of streaming live videos to multiple clients within the LAN with the support of 60fps @8K video stream with the bitrate of 100 Mbps
     * A private media server is expected to be ready on the LAN.
     */
    kRoomProfileTypeLanLiveStreaming = 15,
    /**
     * @brief For meeting Apps installed on personal devices
     */
    kRoomProfileTypeMeeting = 16,
    /**
     * @brief For meeting Apps installed on terminals of meeting rooms, such as Rooms.
     */
    kRoomProfileTypeMeetingRoom = 17,
    /**
     * @brief For the online classrooms and lectures that over 10 participants in the room are allowed to join the video chat.
     */
    kRoomProfileTypeClassroom = 18
}
export declare enum SubscribeFallbackOption {
    kSubscribeFallbackOptionDisable = 0,
    kSubscribeFallbackOptionVideoStreamLow = 1,
    kSubscribeFallbackOptionAudioOnly = 2
}
/**
 * @brief Configuration for the room. Room is a abstract concept for an RTC call. Users can interactive with each other in the same room.
 */
export interface RTCRoomConfig {
    /**
     * @brief Room profile. The setting cannot be changed after joining the room.
     */
    room_profile_type: RoomProfileType;
    /**
     * @brief Whether to publish media streams automatically. The default is automatic publishing.
     *       Only one of the rooms the user joined can be set to auto-publish.
     *        If you call [setUserVisibility](85532#setuservisibility) to set your own visibility to false, you will not publish media streams regardless of the value of `is_auto_publish`.
     */
    is_auto_publish: boolean;
    /**
     * @brief Whether to automatically subscribe to the audio stream. The default is automatic subscription.
     */
    is_auto_subscribe_audio: boolean;
    /**
     * @brief Whether to automatically subscribe to the main video stream. The default is automatic subscription.
     */
    is_auto_subscribe_video: boolean;
    /**
     * @brief Expected configuration of remote video stream
     */
    remote_video_config?: RemoteVideoConfig;
}
export interface SubscribeVideoConfig {
    video_index: number;
    priority: number;
}
export declare enum MirrorMode {
    kMirrorModeOff = 0,
    kMirrorModeOn = 1
}
/**
 * @brief Mirror type
 */
export declare enum MirrorType {
    /**
     * @brief The preview and the published video stream are not mirrored.
     */
    kMirrorTypeNone = 0,
    /**
     * @brief The preview is mirrored. The published video stream is not mirrored.
     */
    kMirrorTypeRender = 1,
    /**
     * @brief The preview and the published video stream are mirrored.
     */
    kMirrorTypeRenderAndEncoder = 3
}
/**
 * @brief Video/audio call test configurations
 */
export interface EchoTestConfig {
    /**
     * @brief Volume prompt interval in ms, the default value is 100.
     *        + `<= 0`: Turn off prompt
     *        + `(0,100]` Invalid interval value, and will be automatically reset to 100ms.
     *        + `> 100`: the actual value of interval
     */
    audioPropertiesReportInterval: number;
    /**
     * @brief User ID for testing
     */
    uid: string;
    /**
     * @brief ID of the room that the tested user will join.
     */
    roomId: string;
    /**
     * @brief Token used for authenticating users when they enter the room.
     */
    token: string;
}
/**
 * @brief Pause/resume receiving the remote media stream type.
 */
export declare enum PauseResumeControlMediaType {
    /**
     * @brief Audio only
     */
    kRTCPauseResumeControlMediaTypeAudio = 0,
    /**
     * @brief Video only
     */
    kRTCPauseResumeControlMediaTypeVideo = 1,
    /**
     * @brief Both video and audio
     */
    kRTCPauseResumeControlMediaTypeVideoAndAudio = 2
}
/**
 * @brief Mixing configuration
 */
export interface AudioMixingConfig {
    /**
     * @brief For mixing playback types.
     */
    type: AudioMixingType;
    play_count: number;
    /**
     * @brief The position of the audio file playback progress bar during audio mixing, the parameter should be an integer, in milliseconds.
     */
    position: number;
    /**
     * @brief Set the time interval (ms) for the audio file playing progress callback. The `onAudioMixingPlayingProgress` callback then will be triggered according to the set value, no callback by default.
     * + The value of interval is a multiple of 10 greater than 0. When the value set is not divisible by 10, the default is rounded up by 10. For example, if the value is set to 52ms, it will be automatically adjusted to 60ms, then the SDK will trigger `onAudioMixingPlayingProgress` callback at the set interval.
     * + If the value is less than or equals to 0, the callback will not be triggered.
     */
    callback_on_progress_interval: number;
}
/**
 * @brief Whether to collect mouse information when collecting screen video stream internally
 */
export declare enum MouseCursorCaptureState {
    /**
     * @brief Collect mouse information
     */
    kMouseCursorCaptureStateOn = 0,
    /**
     * @brief Do not collect mouse information
     */
    kMouseCursorCaptureStateOff = 1
}
/**
 * @brief Screen internal capture parameters
 */
export interface ScreenCaptureParameters {
    /**
     * @brief Collection area.
     */
    region_rect: Rectangle;
    /**
     * @brief To collect mouse status.
     */
    capture_mouse_cursor: MouseCursorCaptureState;
    /**
     * @brief Screen filtering settings. Provide ID of the windows to be excluded.
     */
    filter_config: number[];
    /**
     * @brief Configuration of highlighted borders
     */
    highlight_config: HighlightConfig;
}
/**
 * @brief User info
 */
export declare type UserInfo = {
    /**
     * @brief User ID. The string matches the regular expression: `[a-zA-Z0-9_@\-]{1,128}`.
     */
    uid: string;
    /**
     * @brief Additional information of the user. The maximum length is 200 bytes. The remote user will receive the info in [onUserJoined](85533#onuserjoined).
     */
    extra_info?: string;
};
/**
 * @brief Information on remote video frame
 */
export interface RemoteVideoConfig {
    /**
     * @brief Expected maximum frame rate of the subscribed stream in px. The default value is 0, values greater than 10 are valid.
     *        If the frame rate of the stream published is lower than the value you set, or if your subscribed stream falls back under limited network conditions, the frame rate you set will drop accordingly.
     *        Only valid if the stream is coded with SVC technique.
     */
    framerate: number;
    /**
     * @brief Width of the video frame in px
     */
    resolution_width: number;
    /**
     * @brief Height of the video frame in px
     */
    resolution_height: number;
}
/**
 * @brief Media stream type
 */
export declare enum MediaStreamType {
    /**
     * @brief Audio only
     */
    kMediaStreamTypeAudio = 1,
    /**
     * @brief Video only
     */
    kMediaStreamTypeVideo = 2,
    /**
     * @brief Both audio and video
     */
    kMediaStreamTypeBoth = 3
}
/**
 * @brief Basic beauty effect.
 */
export declare enum EffectBeautyMode {
    /**
     * @brief Brightness.
     */
    kEffectBeautyWhite = 0,
    /**
     * @brief Smoothness.
     */
    kEffectBeautySmooth = 1,
    /**
     * @brief Sharpness.
     */
    kEffectBeautySharpen = 2
}
/**
 * @brief Mix playback channel type
 */
export declare enum AudioMixingDualMonoMode {
    /**
     * @brief Consistent with audio files
     */
    kAudioMixingDualMonoModeAuto = 0,
    /**
     * @brief Only the left channel audio in the audio file can be heard
     */
    kAudioMixingDualMonoModeL = 1,
    /**
     * @brief Only the right channel audio in the audio file can be heard
     */
    kAudioMixingDualMonoModeR = 2,
    /**
     * @brief Can hear the left and right audio channels in the audio file at the same time
     */
    kAudioMixingDualMonoModeMix = 3
}
/**
 * @brief RTM message
 */
export declare enum MessageConfig {
    /**
     * @brief Low latency reliable and orderly message
     */
    kMessageConfigReliableOrdered = 0,
    /**
     * @brief Ultra-low latency ordered message
     */
    kMessageConfigUnreliableOrdered = 1,
    /**
     * @brief Ultra-low latency unordered message
     */
    kMessageConfigUnreliableUnordered = 2
}
/**
 * @brief A/V synchronization states
 */
export declare enum AVSyncState {
    /**
     * @brief A/V synchronization begins.
     */
    kAVSyncStateAVStreamSyncBegin = 0,
    /**
     * @brief The publisher stops publishing audio stream during the synchronization, which does not affect the sync relationship.
     */
    kAVSyncStateAudioStreamRemove = 1,
    /**
     * @brief The publisher stops publishing audio stream during the synchronization, which does not affect the sync relationship.
     */
    kAVSyncStateVdieoStreamRemove = 2,
    /**
     * @hidden
     * @brief Subscriber settings synchronization
     */
    kAVSyncStateSetAVSyncStreamId = 3
}
/**
 * @brief The state of the relaying for each room
 */
export declare enum ForwardStreamState {
    /**
     * @brief Idle
     *        + States of all the rooms turns to idle after you call `stopForwardStreamToRooms`.
     *        + States of the rooms turns to idle that you call `updateForwardStreamToRooms` to remove.
     */
    kForwardStreamStateIdle = 0,
    /**
     * @brief Start relaying.
     *        + State of the rooms turn to this state after the relaying starts successfully by calling `startForwardStreamToRooms`.
     *        + State of the rooms added by calling `updateForwardStreamToRooms` turn to this state after the relaying start successfully.
     */
    kForwardStreamStateSuccess = 1,
    /**
     * @brief Relay fails. Refer to [ForwardStreamError](85534#forwardstreamerror) for more information for more information.
     *        Once the relaying fails, state of the room turns to this state after calling `startForwardStreamToRooms` or `updateForwardStreamToRooms`.
     */
    kForwardStreamStateFailure = 2
}
/**
 * @detail 85534
 * @brief Error codes during the relaying
 */
export declare enum ForwardStreamError {
    /**
     * @brief Normal
     */
    kForwardStreamErrorOK = 0,
    /**
     * @brief Invalid argument
     */
    kForwardStreamErrorInvalidArgument = 1201,
    /**
     * @brief Invalid token
     */
    kForwardStreamErrorInvalidToken = 1202,
    /**
     * @brief Error returning from server
     */
    kForwardStreamErrorResponse = 1203,
    /**
     * @brief Relaying aborts for the reason of that a User with the same user ID as that of the publisher joins.
     */
    kForwardStreamErrorRemoteKicked = 1204,
    /**
     * @brief Server denies.
     */
    kForwardStreamErrorNotSupport = 1205
}
/**
 * @brief State and error for each room during relaying
 */
export interface ForwardStreamStateInfo {
    /**
     * @brief ID of the room where the media stream aims to relay to
     *        An Empty string is for all rooms.
     */
    room_id: string;
    /**
     * @brief State of the room during relaying.
     */
    state: ForwardStreamState;
    /**
     * @brief Error code from the room during relaying.
     */
    error: ForwardStreamError;
}
/**
 * @brief Information of the rooms where you want to relay the media stream to
 */
export interface ForwardStreamInfo {
    /**
     * @brief RoomId and UserId are required to generate the Token to forward media streams to the room.
     *        During developing and testing, you can use temporary tokens generated on the console. At the production stage, Tokens are generated by the token generating application deployed on your server.
     *        Forwarding will fail if the token is invalid.
     */
    token: string;
    /**
     * @brief ID of the room where the media stream aims to relay to
     */
    room_id: string;
}
/**
 * @brief Information of the rooms where you want to relay the media stream to
 */
export interface ForwardStreamConfiguration {
    /**
     * @brief Information of the rooms where you want to relay the media stream to
     */
    forward_stream_dests: ForwardStreamInfo[];
    /**
     * @brief Number of the rooms where you want to relay the media stream
     *        We recommend that the number is not higher than 4.
     */
    dest_count: number;
}
/**
 * @brief Events during the relaying
 */
export declare enum ForwardStreamEvent {
    /**
     * @brief Relaying pauses for the reason of network disconnecting.
     */
    kForwardStreamEventDisconnected = 0,
    /**
     * @brief Relaying recovers from the disconnecting.
     */
    kForwardStreamEventConnected = 1,
    /**
     * @brief Relaying aborts for the reason of that a User with the same user ID as that of the publisher joins.
     */
    kForwardStreamEventInterrupt = 2,
    /**
     * @brief Target room list updates after you call `updateForwardStreamToRooms`.
     */
    kForwardStreamEventDstRoomUpdated = 3,
    /**
     * @brief Wrong API-calling order. For example, call `updateForwardStreamToRooms` before calling `startForwardStreamToRooms`.
     */
    kForwardStreamEventUnExpectAPICall = 4
}
/**
 * @brief Event from each room during relaying
 */
export interface ForwardStreamEventInfo {
    /**
     * @brief ID of the room where the media stream aims to relay to
     *        An Empty string is for all rooms.
     */
    room_id: string;
    /**
     * @brief Event from the room during relaying.
     */
    event: ForwardStreamEvent;
}
/**
 * @brief Tx/Rx network quality
 */
export interface NetworkQualityStats {
    /**
     * @brief User ID
     */
    uid: string;
    /**
     * @brief Packet loss ratio of the local client, ranging [0.0,1.0]
     *        For a local user, it is the sent-packet loss ratio.
     *        For a remote user, it is the loss ratio of all the packets received.
     */
    fraction_lost: number;
    /**
     * @brief Round-trip time (RTT) from client to server. Effective for the local user. Unit: ms
     */
    rtt: number;
    /**
     * @brief Rx network quality grade.
     */
    rx_quality: NetworkQuality;
    /**
     * @brief Average transmission rate of the media RTP packages in 2s. unit: bps
     *        For a local user, it is the packet-transmitting speed.
     *        For a more user, it is the speed of receiving all the subsribed media.
     */
    total_bandwidth: number;
    /**
     * @brief Rx network quality grade.
     */
    tx_quality: NetworkQuality;
}
/**
 * @brief The range where local user can hear audio with attenuation effect.
 */
export declare type ReceiveRange = {
    /**
     * @brief The minimum distance at which the local user can hear the attenuated audio from remote users.
     *        The value must be ≥ 0, but ≤ max.
     *        No attenuation effect for audio from distances less than this value you set.
     */
    max: number;
    /**
     * @brief The maximum distance at which the local user can hear audio from remote users.
     *        The value must be ≥ min, and > 0.
     *        Audio from distances larger than the value you set cannot be heard.
     */
    min: number;
};
/**
 * @brief Coordinate value of the local user's position in the rectangular coordinate system in the RTC room.
 */
export declare type Position = {
    /**
     * @brief X-coordinate
     */
    x: number;
    /**
     * @brief Y-coordinate
     */
    y: number;
    /**
     * @brief Z-coordinate
     */
    z: number;
};
/**
 * @brief Volume Roll-off modes that a sound has in an audio source
 */
export declare enum AttenuationType {
    /**
     * @brief Disable Volume Attenuation
     */
    kAttenuationTypeNone = 0,
    /**
     * @brief Linear roll-off mode which lowers the volume of the sound over the distance
     */
    kAttenuationTypeLinear = 1,
    /**
     * @brief Exponential roll-off mode which exponentially decreases the volume of the sound with the distance raising
     */
    kAttenuationTypeExponential = 2
}
/**
 * @brief Orientation
 */
export interface Orientation {
    /**
     * @brief The angle the vector makes with the x-axis
     */
    x: number;
    /**
     * @brief The angle the vector makes with the y-axis
     */
    y: number;
    /**
     * @brief The angle the vector makes with the z-axis
     */
    z: number;
}
/**
 * @brief Three-dimensional orientation information, each pair of vectors need to be perpendicular.
 */
export interface HumanOrientation {
    /**
     * @brief Forward orientation, the default value is {1,0,0}, i.e., the forward orientation is in the positive direction of x-axis.
     */
    forward: Orientation;
    /**
     * @brief Rightward orientation, the default value is {0,1,0}, i.e., the rightward orientation is in the positive direction of y-axis.
     */
    right: Orientation;
    /**
     * @brief Upward orientation, the default value is {0,0,1}, i.e., the upward orientation is in the positive direction of z-axis.
     */
    up: Orientation;
}
/**
 * @brief Range audio stream information
 */
export declare type RangeAudioInfo = {
    /**
     * @brief ID of remote stream publisher
     */
    user_id: string;
    /**
     * @brief Attenuation coefficient of the remote user. The value range is [0,100].
     *        A value of 0 means that the remote user's audio volume is 0.
     */
    factor: number;
};
/**
 * @brief Encoder preference
 */
export declare enum VideoEncodePreference {
    /**
     * @brief No preference
     */
    kVideoEncodePreferenceDisabled = 0,
    /**
     * @brief Frame rate first
     */
    kVideoEncodePreferenceFramerate = 1,
    /**
     * @brief Quality first
     */
    kVideoEncodePreferenceQuality = 2,
    /**
     * @brief Balancing quality and frame rate
     */
    kVideoEncodePreferenceBalance = 3
}
/**
 * @brief Video capture preference
 */
export declare enum CapturePreference {
    /**
     * @brief (Default) Video capture preference: auto
     *        SDK determines the best video capture parameters referring to the camera output parameters and the encoder configuration.
     */
    KAuto = 0,
    /**
     * @brief Video capture preference: manual
     *        Set the resolution and the frame rate manually.
     */
    KManual = 1,
    /**
     * @brief Video capture preference: encoder configuration
     *        The capture parameters are the same with the parameters set in [setVideoEncoderConfig](85532#setvideoencoderconfig).
     */
    KAutoPerformance = 2
}
/**
 * @brief Video capture configuration parameters.
 */
export declare type VideoCaptureConfig = {
    /**
     * @brief Video capture preference
     */
    capturePreference: CapturePreference;
    /**
     * @brief The width of video capture resolution in px.
     */
    width: number;
    /**
     * @brief The height of video capture resolution in px.
     */
    height: number;
    /**
     * @brief Video capture frame rate in fps.
     */
    frameRate: number;
};
/**
 * @brief Watermark configurations
 */
export interface RTCWatermarkConfig {
    /**
     * @brief Whether the watermark is visible in preview. Its default value is `true`.
     */
    visibleInPreview: boolean;
    /**
     * @brief Watermark's coordinates and size in landscape mode.
     */
    positionInLandscapeMode: ByteWatermark;
    /**
     * @brief Watermark's coordinates and size in portrait mode.
     */
    positionInPortraitMode: ByteWatermark;
}
/**
 * @brief Watermark's scaled coordinates and size, relative to the video stream.
 */
export interface ByteWatermark {
    /**
     * @brief The watermark's horizontal offset from the upper left corner of the video stream to the video stream's width in range of [0,1).
     */
    x: number;
    /**
     * @brief The watermark's vertical offset from the upper left corner of the video stream to the video stream's width in range of [0,1).
     */
    y: number;
    /**
     * @brief The watermark's vertical offset from the upper left corner of the video stream to the video stream's height in range of [0,1).
     */
    width: number;
    /**
     * @brief The watermark's width to the video stream's width in range of [0,1).
     */
    height: number;
}
export interface SourceWantedData {
    /**
     * @brief  <br>
     * 未开启发布回退时，此值表示推荐的视频输入宽度，当回退模式为大小流模式时，表示当前推流的最大宽度
     * @brief 如果未开启发送性能回退，此值表示推荐的视频输入宽度；  <br>
     *        如果开启了发送性能回退，此值表示当前推流的最大宽度。
     */
    width: number;
    /**
     * @brief 如果未开启发送性能回退，此值表示推荐的视频输入高度；<br>
     *        如果开启了发送性能回退，此值表示当前推流的最大高度。
     */
    heigth: number;
    /**
     * @brief 如果未开启发送性能回退，此值表示推荐的视频输入帧率，单位 fps；<br>
     *        如果开启了发送性能回退，此值表示当前推流的最大帧率，单位 fps。
     */
    frame_rate: number;
}
export declare enum EchoTestResult {
    /**
     * @brief 接收到采集的音视频的回放，通话回路检测成功
     */
    kTestSuccess = 0,
    /**
     * @brief 测试超过 60s 仍未完成，已自动停止
     */
    kTestTimeout = 1,
    /**
     * @brief 上一次测试结束和下一次测试开始之间的时间间隔少于 5s
     */
    kTestIntervalShort = 2,
    /**
     * @brief 音频采集异常
     */
    kAudioDeviceError = 3,
    /**
     * @brief 视频采集异常
     */
    kVideoDeviceError = 4,
    /**
     * @brief 音频接收异常
     */
    kAudioReceiveError = 5,
    /**
     * @brief 视频接收异常
     */
    kVideoReceiveError = 6,
    /**
     * @brief 内部错误，不可恢复
     */
    kInternalError = 7
}
