"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright 2022 BytePlus Pte. Ltd.
 * SPDX-License-Identifier: MIT
 */
const YUVCanvas = require("yuv-canvas");
const types_1 = require("../types");
class YUVRender {
    constructor(element, renderMode = types_1.RenderMode.FIT, mirror, context) {
        this.destroied = false;
        // [parentDiv [containerDiv [canvas ]]];
        this.parent = element;
        this.renderMode = renderMode;
        this.container = document.createElement("div");
        this.mirror_ = mirror;
        this.context_ = context || {};
        // this.container.style.border = '1px solid red'; // for debug
        Object.assign(this.container.style, {
            width: "100%",
            height: "100%",
            display: "flex",
            justifyContent: "center",
            alignItems: "center",
            backgroundColor: "black",
        });
        this.canvas = document.createElement("canvas");
        this.canvas.setAttribute("style", "overflow: hidden");
        this.parent.appendChild(this.container);
        this.container.appendChild(this.canvas);
        // by my test results, it will cose averate 12ms to render a YUV frame if webGL is off
        // and it will cost about 3ms whe webGL is on
        //直接使用内部的判断逻辑
        this.yuvCanvas = YUVCanvas.attach(this.canvas, { webGl: false });
    }
    // see https://github.com/brion/yuv-buffer
    static buildYUVFrame(data) {
        const { width, height, plane_y, plane_u, plane_v, plane_size_y, plane_size_u, plane_size_v, rotation, } = data;
        let frame = {
            format: {
                width: width,
                height: height,
                chromaWidth: width / 2,
                chromaHeight: height / 2,
                cropLeft: 0,
                cropTop: 0,
                cropWidth: width,
                cropHeight: height,
                displayWidth: width,
                displayHeight: height,
                rotation: rotation,
            },
            y: { bytes: plane_y, stride: plane_size_y },
            u: { bytes: plane_u, stride: plane_size_u },
            v: { bytes: plane_v, stride: plane_size_v },
        };
        return frame;
    }
    destroy() {
        if (!this.destroied) {
            this.yuvCanvas.clear();
            this.canvas.remove();
            this.container.remove();
            this.yuvCanvas = null;
            this.destroied = true;
        }
    }
    setMirrorType(mirror) {
        this.mirror_ = mirror;
    }
    clearFrame() {
        if (this.yuvCanvas) {
            this.yuvCanvas.clear();
        }
        else {
            console.warn("call renderFrame, but yuvCanvas is null");
        }
    }
    renderFrame(frame) {
        if (this.yuvCanvas) {
            this.adjustRender(frame);
            if (this.context_.flagNotRenderFrame) {
            }
            else {
                this.yuvCanvas.drawFrame(frame);
            }
        }
        else {
            console.warn("call renderFrame, but yuvCanvas is null");
        }
    }
    adjustRender(frame) {
        let containerRatio = this.container.clientWidth / this.container.clientHeight;
        let targetWidth;
        let targetHeight;
        if (frame.format.rotation === 90 || frame.format.rotation === 270) {
            targetWidth = frame.format.height;
            targetHeight = frame.format.width;
        }
        else {
            targetWidth = frame.format.width;
            targetHeight = frame.format.height;
        }
        let frameRatio = targetWidth / targetHeight;
        switch (this.renderMode) {
            case types_1.RenderMode.HIDDEN:
                {
                    if (containerRatio >= frameRatio) {
                        this.canvas.style.zoom = String(this.container.clientWidth / targetWidth);
                    }
                    else {
                        this.canvas.style.zoom = String(this.container.clientHeight / targetHeight);
                    }
                    let transform = "rotateZ(" + frame.format.rotation.toString() + "deg)";
                    if (this.mirror_) {
                        transform += " rotateY(180deg)";
                    }
                    this.canvas.style.transform = transform;
                }
                break;
            case types_1.RenderMode.FIT:
                {
                    if (containerRatio >= frameRatio) {
                        this.canvas.style.zoom = String(this.container.clientHeight / targetHeight);
                    }
                    else {
                        this.canvas.style.zoom = String(this.container.clientWidth / targetWidth);
                    }
                    let transform = "rotateZ(" + frame.format.rotation.toString() + "deg)";
                    if (this.mirror_) {
                        transform += " rotateY(180deg)";
                    }
                    this.canvas.style.transform = transform;
                }
                break;
            default:
                {
                    console.warn(`adjustRender with an unexpected mode: ${this.renderMode}`);
                }
                break;
        }
    }
}
exports.YUVRender = YUVRender;
//# sourceMappingURL=yuv_render.js.map